@@ -87,7 +87,7 @@ struct FileFuncDefs
   /**
    * Callback for reading 'size' bytes from the ZIP archive into buf.
    */
-  uLong (*zread_file) (voidpf opaque, void* buf, uLong size);
+  uLong (*zread_file) (voidpf opaque, void*buf, uLong size);
 
   /**
    * Callback to obtain the current read offset in the ZIP archive.
@@ -114,7 +114,8 @@ struct FileFuncDefs
  * @param size number of bytes to read
  * @return number of bytes copied to buf
  */
-#define ZREAD(filefunc,buf,size) ((*((filefunc).zread_file)) ((filefunc).opaque, buf, size))
+#define ZREAD(filefunc,buf,size) ((*((filefunc).zread_file))((filefunc).opaque, \
+                                                             buf, size))
 
 /**
  * Macro to obtain current offset in file using filefunc API.
@@ -122,7 +123,7 @@ struct FileFuncDefs
  * @param filefunc filefunc struct
  * @return current offset in file
  */
-#define ZTELL(filefunc) ((*((filefunc).ztell_file)) ((filefunc).opaque))
+#define ZTELL(filefunc) ((*((filefunc).ztell_file))((filefunc).opaque))
 
 /**
  * Macro to seek using filefunc API.
@@ -132,7 +133,8 @@ struct FileFuncDefs
  * @param mode seek mode
  * @return 0 on success
  */
-#define ZSEEK(filefunc,pos,mode) ((*((filefunc).zseek_file)) ((filefunc).opaque, pos, mode))
+#define ZSEEK(filefunc,pos,mode) ((*((filefunc).zseek_file))((filefunc).opaque, \
+                                                             pos, mode))
 
 
 /**
@@ -208,7 +210,7 @@ struct FileInZipReadInfo
   /**
    * size of the local extra field
    */
-  uInt  size_local_extrafield;
+  uInt size_local_extrafield;
 
   /**
    * position in the local extra field in read
@@ -337,7 +339,7 @@ struct EXTRACTOR_UnzipFile
  */
 static int
 read_byte_from_ffd (const struct FileFuncDefs *ffd,
-		    int *pi)
+                    int *pi)
 {
   unsigned char c;
 
@@ -359,7 +361,7 @@ read_byte_from_ffd (const struct FileFuncDefs *ffd,
  */
 static int
 read_short_from_ffd (const struct FileFuncDefs *ffd,
-		     uLong *pX)
+                     uLong *pX)
 {
   uLong x;
   int i;
@@ -388,7 +390,7 @@ read_short_from_ffd (const struct FileFuncDefs *ffd,
  */
 static int
 read_long_from_ffd (const struct FileFuncDefs *ffd,
-		    uLong *pX)
+                    uLong *pX)
 {
   uLong x;
   int i;
@@ -413,7 +415,7 @@ read_long_from_ffd (const struct FileFuncDefs *ffd,
 
 
 #ifndef CASESENSITIVITYDEFAULT_NO
-#if !defined(unix) && !defined(CASESENSITIVITYDEFAULT_YES)
+#if ! defined(unix) && ! defined(CASESENSITIVITYDEFAULT_YES)
 #define CASESENSITIVITYDEFAULT_NO
 #endif
 #endif
@@ -436,14 +438,14 @@ read_long_from_ffd (const struct FileFuncDefs *ffd,
  * @return 0 if names are equal
  */
 static int
-EXTRACTOR_common_unzip_string_file_name_compare (const char* fileName1,
-						 const char* fileName2,
-						 int iCaseSensitivity)
+EXTRACTOR_common_unzip_string_file_name_compare (const char*fileName1,
+                                                 const char*fileName2,
+                                                 int iCaseSensitivity)
 {
   if (0 == iCaseSensitivity)
     iCaseSensitivity = CASESENSITIVITYDEFAULTVALUE;
   if (1 == iCaseSensitivity)
-    return strcmp(fileName1, fileName2);
+    return strcmp (fileName1, fileName2);
   return strcasecmp (fileName1, fileName2);
 }
 
@@ -474,31 +476,31 @@ locate_central_directory (const struct FileFuncDefs *ffd)
     uMaxBack = uSizeFile;
   uBackRead = 4;
   while (uBackRead < uMaxBack)
-    {
-      uLong uReadSize;
-      uLong uReadPos;
-      int i;
+  {
+    uLong uReadSize;
+    uLong uReadPos;
+    int i;
 
-      if (uBackRead + BUFREADCOMMENT > uMaxBack)
-	uBackRead = uMaxBack;
-      else
-	uBackRead += BUFREADCOMMENT;
-      uReadPos = uSizeFile - uBackRead;
-      uReadSize = ((BUFREADCOMMENT + 4) < (uSizeFile - uReadPos))
-	? (BUFREADCOMMENT + 4)
-	: (uSizeFile - uReadPos);
-      if (0 != ZSEEK (*ffd, uReadPos, SEEK_SET))
-	break;
-      if (ZREAD (*ffd, buf, uReadSize) != uReadSize)
-	break;
-      i = (int) uReadSize - 3;
-      while (i-- > 0)
-	if ( (0x50 == (*(buf+i))) &&
-	     (0x4b == (*(buf+i+1))) &&
-	     (0x05 == (*(buf+i+2))) &&
-	     (0x06 == (*(buf+i+3))) )
-	  return uReadPos + i;
-    }
+    if (uBackRead + BUFREADCOMMENT > uMaxBack)
+      uBackRead = uMaxBack;
+    else
+      uBackRead += BUFREADCOMMENT;
+    uReadPos = uSizeFile - uBackRead;
+    uReadSize = ((BUFREADCOMMENT + 4) < (uSizeFile - uReadPos))
+                ? (BUFREADCOMMENT + 4)
+                : (uSizeFile - uReadPos);
+    if (0 != ZSEEK (*ffd, uReadPos, SEEK_SET))
+      break;
+    if (ZREAD (*ffd, buf, uReadSize) != uReadSize)
+      break;
+    i = (int) uReadSize - 3;
+    while (i-- > 0)
+      if ( (0x50 == (*(buf + i))) &&
+           (0x4b == (*(buf + i + 1))) &&
+           (0x05 == (*(buf + i + 2))) &&
+           (0x06 == (*(buf + i + 3))) )
+        return uReadPos + i;
+  }
   return 0;
 }
 
@@ -512,7 +514,7 @@ locate_central_directory (const struct FileFuncDefs *ffd)
  */
 static void
 dos_date_to_tmu_date (uLong ulDosDate,
-			   struct EXTRACTOR_UnzipDateTimeInfo* ptm)
+                      struct EXTRACTOR_UnzipDateTimeInfo*ptm)
 {
   uLong uDate;
 
@@ -543,14 +545,14 @@ dos_date_to_tmu_date (uLong ulDosDate,
  */
 static int
 get_current_file_info (struct EXTRACTOR_UnzipFile *file,
-		       struct EXTRACTOR_UnzipFileInfo *pfile_info,
-		       struct UnzipFileInfoInternal *pfile_info_internal,
-		       char *szFileName,
-		       uLong fileNameBufferSize,
-		       void *extraField,
-		       uLong extraFieldBufferSize,
-		       char *szComment,
-		       uLong commentBufferSize)
+                       struct EXTRACTOR_UnzipFileInfo *pfile_info,
+                       struct UnzipFileInfoInternal *pfile_info_internal,
+                       char *szFileName,
+                       uLong fileNameBufferSize,
+                       void *extraField,
+                       uLong extraFieldBufferSize,
+                       char *szComment,
+                       uLong commentBufferSize)
 {
   struct EXTRACTOR_UnzipFileInfo file_info;
   struct UnzipFileInfoInternal file_info_internal;
@@ -560,128 +562,130 @@ get_current_file_info (struct EXTRACTOR_UnzipFile *file,
   if (NULL == file)
     return EXTRACTOR_UNZIP_PARAMERROR;
   if (0 != ZSEEK (file->z_filefunc,
-		  file->pos_in_central_dir + file->byte_before_the_zipfile,
-		  SEEK_SET))
+                  file->pos_in_central_dir + file->byte_before_the_zipfile,
+                  SEEK_SET))
     return EXTRACTOR_UNZIP_ERRNO;
 
   /* we check the magic */
   if (EXTRACTOR_UNZIP_OK !=
-      read_long_from_ffd(&file->z_filefunc, &uMagic))
+      read_long_from_ffd (&file->z_filefunc, &uMagic))
     return EXTRACTOR_UNZIP_ERRNO;
   if (0x02014b50 != uMagic)
     return EXTRACTOR_UNZIP_BADZIPFILE;
 
   if ( (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd (&file->z_filefunc, &file_info.version)) ||
+        read_short_from_ffd (&file->z_filefunc, &file_info.version)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd (&file->z_filefunc, &file_info.version_needed)) ||
+        read_short_from_ffd (&file->z_filefunc, &file_info.version_needed)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd (&file->z_filefunc, &file_info.flag)) ||
+        read_short_from_ffd (&file->z_filefunc, &file_info.flag)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd (&file->z_filefunc, &file_info.compression_method)) ||
+        read_short_from_ffd (&file->z_filefunc,
+                             &file_info.compression_method)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_long_from_ffd (&file->z_filefunc, &file_info.dosDate)) )
+        read_long_from_ffd (&file->z_filefunc, &file_info.dosDate)) )
     return EXTRACTOR_UNZIP_ERRNO;
   dos_date_to_tmu_date (file_info.dosDate,
-			&file_info.tmu_date);
+                        &file_info.tmu_date);
   if ( (EXTRACTOR_UNZIP_OK !=
-	read_long_from_ffd(&file->z_filefunc, &file_info.crc)) ||
+        read_long_from_ffd (&file->z_filefunc, &file_info.crc)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_long_from_ffd(&file->z_filefunc, &file_info.compressed_size)) ||
+        read_long_from_ffd (&file->z_filefunc, &file_info.compressed_size)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_long_from_ffd(&file->z_filefunc, &file_info.uncompressed_size)) ||
+        read_long_from_ffd (&file->z_filefunc, &file_info.uncompressed_size)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd(&file->z_filefunc, &file_info.size_filename)) ||
+        read_short_from_ffd (&file->z_filefunc, &file_info.size_filename)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd(&file->z_filefunc, &file_info.size_file_extra)) ||
+        read_short_from_ffd (&file->z_filefunc, &file_info.size_file_extra)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd(&file->z_filefunc, &file_info.size_file_comment)) ||
+        read_short_from_ffd (&file->z_filefunc,
+                             &file_info.size_file_comment)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd(&file->z_filefunc, &file_info.disk_num_start)) ||
+        read_short_from_ffd (&file->z_filefunc, &file_info.disk_num_start)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd(&file->z_filefunc, &file_info.internal_fa)) ||
+        read_short_from_ffd (&file->z_filefunc, &file_info.internal_fa)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_long_from_ffd(&file->z_filefunc, &file_info.external_fa)) ||
+        read_long_from_ffd (&file->z_filefunc, &file_info.external_fa)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_long_from_ffd (&file->z_filefunc,
-			    &file_info_internal.offset_curfile)) )
+        read_long_from_ffd (&file->z_filefunc,
+                            &file_info_internal.offset_curfile)) )
     return EXTRACTOR_UNZIP_ERRNO;
 
   lSeek += file_info.size_filename;
   if (NULL != szFileName)
+  {
+    uLong uSizeRead;
+
+    if (file_info.size_filename < fileNameBufferSize)
     {
-      uLong uSizeRead;
-
-      if (file_info.size_filename < fileNameBufferSize)
-        {
-	  *(szFileName + file_info.size_filename) = '\0';
-	  uSizeRead = file_info.size_filename;
-        }
-      else
-	uSizeRead = fileNameBufferSize;
-
-      if ( (file_info.size_filename > 0) &&
-	   (fileNameBufferSize > 0) )
-	if (ZREAD(file->z_filefunc, szFileName, uSizeRead) != uSizeRead)
-	  return EXTRACTOR_UNZIP_ERRNO;
-      lSeek -= uSizeRead;
+      *(szFileName + file_info.size_filename) = '\0';
+      uSizeRead = file_info.size_filename;
     }
+    else
+      uSizeRead = fileNameBufferSize;
+
+    if ( (file_info.size_filename > 0) &&
+         (fileNameBufferSize > 0) )
+      if (ZREAD (file->z_filefunc, szFileName, uSizeRead) != uSizeRead)
+        return EXTRACTOR_UNZIP_ERRNO;
+    lSeek -= uSizeRead;
+  }
 
   if (NULL != extraField)
+  {
+    uLong uSizeRead;
+
+    if (file_info.size_file_extra<extraFieldBufferSize)
+      uSizeRead = file_info.size_file_extra;
+    else
+      uSizeRead = extraFieldBufferSize;
+
+    if (0 != lSeek)
     {
-      uLong uSizeRead;
-
-      if (file_info.size_file_extra<extraFieldBufferSize)
-	uSizeRead = file_info.size_file_extra;
+      if (0 == ZSEEK (file->z_filefunc, lSeek, SEEK_CUR))
+        lSeek = 0;
       else
-	uSizeRead = extraFieldBufferSize;
-
-      if (0 != lSeek)
-	{
-	  if (0 == ZSEEK (file->z_filefunc, lSeek, SEEK_CUR))
-	    lSeek = 0;
-	  else
-	    return EXTRACTOR_UNZIP_ERRNO;
-	}
-      if ( (file_info.size_file_extra > 0) &&
-	   (extraFieldBufferSize > 0) &&
-	   (ZREAD (file->z_filefunc,
-		   extraField,
-		   uSizeRead) != uSizeRead) )
-	return EXTRACTOR_UNZIP_ERRNO;
-      lSeek += file_info.size_file_extra - uSizeRead;
+        return EXTRACTOR_UNZIP_ERRNO;
     }
+    if ( (file_info.size_file_extra > 0) &&
+         (extraFieldBufferSize > 0) &&
+         (ZREAD (file->z_filefunc,
+                 extraField,
+                 uSizeRead) != uSizeRead) )
+      return EXTRACTOR_UNZIP_ERRNO;
+    lSeek += file_info.size_file_extra - uSizeRead;
+  }
   else
     lSeek += file_info.size_file_extra;
 
   if (NULL != szComment)
+  {
+    uLong uSizeRead;
+
+    if (file_info.size_file_comment < commentBufferSize)
     {
-      uLong uSizeRead;
-
-      if (file_info.size_file_comment < commentBufferSize)
-        {
-	  *(szComment+file_info.size_file_comment) = '\0';
-	  uSizeRead = file_info.size_file_comment;
-        }
-      else
-        {
-          *(szComment+commentBufferSize - 1) = '\0';
-          uSizeRead = commentBufferSize - 1;
-        }
-
-      if (0 != lSeek)
-	{
-	  if (0 == ZSEEK (file->z_filefunc, lSeek, SEEK_CUR))
-	    lSeek = 0;
-	  else
-	    return EXTRACTOR_UNZIP_ERRNO;
-	}
-      if ( (file_info.size_file_comment > 0) &&
-	   (commentBufferSize > 0) &&
-	   (ZREAD (file->z_filefunc, szComment, uSizeRead) != uSizeRead) )
-	return EXTRACTOR_UNZIP_ERRNO;
-      lSeek += file_info.size_file_comment - uSizeRead;
+      *(szComment + file_info.size_file_comment) = '\0';
+      uSizeRead = file_info.size_file_comment;
     }
+    else
+    {
+      *(szComment + commentBufferSize - 1) = '\0';
+      uSizeRead = commentBufferSize - 1;
+    }
+
+    if (0 != lSeek)
+    {
+      if (0 == ZSEEK (file->z_filefunc, lSeek, SEEK_CUR))
+        lSeek = 0;
+      else
+        return EXTRACTOR_UNZIP_ERRNO;
+    }
+    if ( (file_info.size_file_comment > 0) &&
+         (commentBufferSize > 0) &&
+         (ZREAD (file->z_filefunc, szComment, uSizeRead) != uSizeRead) )
+      return EXTRACTOR_UNZIP_ERRNO;
+    lSeek += file_info.size_file_comment - uSizeRead;
+  }
   else
     lSeek += file_info.size_file_comment;
 
@@ -709,9 +713,9 @@ EXTRACTOR_common_unzip_go_to_first_file (struct EXTRACTOR_UnzipFile *file)
   file->pos_in_central_dir = file->offset_central_dir;
   file->num_file = 0;
   err = get_current_file_info (file,
-			       &file->cur_file_info,
-			       &file->cur_file_info_internal,
-			       NULL, 0, NULL, 0, NULL, 0);
+                               &file->cur_file_info,
+                               &file->cur_file_info_internal,
+                               NULL, 0, NULL, 0, NULL, 0);
   file->current_file_ok = (EXTRACTOR_UNZIP_OK == err);
   return err;
 }
@@ -731,12 +735,12 @@ unzip_open_using_ffd (struct FileFuncDefs *ffd)
   uLong central_pos;
   uLong uL;
   uLong number_disk;          /* number of the current dist, used for
-				 spaning ZIP, unsupported, always 0*/
+         spaning ZIP, unsupported, always 0*/
   uLong number_disk_with_CD;  /* number of the disk with central dir, used
-				 for spaning ZIP, unsupported, always 0*/
+         for spaning ZIP, unsupported, always 0*/
   uLong number_entry_CD;      /* total number of entries in
-				 the central dir
-				 (same than number_entry on nospan) */
+         the central dir
+         (same than number_entry on nospan) */
 
   memset (&us, 0, sizeof(us));
   us.z_filefunc = *ffd;
@@ -744,7 +748,7 @@ unzip_open_using_ffd (struct FileFuncDefs *ffd)
   if (0 == central_pos)
     return NULL;
   if (0 != ZSEEK (us.z_filefunc,
-		  central_pos, SEEK_SET))
+                  central_pos, SEEK_SET))
     return NULL;
 
   /* the signature, already checked */
@@ -796,8 +800,8 @@ unzip_open_using_ffd (struct FileFuncDefs *ffd)
   if ((central_pos < us.offset_central_dir + us.size_central_dir))
     return NULL;
 
-  us.byte_before_the_zipfile = central_pos -
-    (us.offset_central_dir + us.size_central_dir);
+  us.byte_before_the_zipfile = central_pos
+                               - (us.offset_central_dir + us.size_central_dir);
   us.central_pos = central_pos;
   us.pfile_in_zip_read = NULL;
   us.encrypted = 0;
@@ -818,7 +822,7 @@ unzip_open_using_ffd (struct FileFuncDefs *ffd)
 int
 EXTRACTOR_common_unzip_close_current_file (struct EXTRACTOR_UnzipFile *file)
 {
-  struct FileInZipReadInfo* pfile_in_zip_read_info;
+  struct FileInZipReadInfo*pfile_in_zip_read_info;
   int err = EXTRACTOR_UNZIP_OK;
 
   if (NULL == file)
@@ -868,8 +872,8 @@ EXTRACTOR_common_unzip_close (struct EXTRACTOR_UnzipFile *file)
  */
 int
 EXTRACTOR_common_unzip_get_global_comment (struct EXTRACTOR_UnzipFile *file,
-					   char *comment,
-					   size_t comment_len)
+                                           char *comment,
+                                           size_t comment_len)
 {
   if (NULL == file)
     return EXTRACTOR_UNZIP_PARAMERROR;
@@ -901,19 +905,20 @@ EXTRACTOR_common_unzip_get_global_comment (struct EXTRACTOR_UnzipFile *file,
  * @return #EXTRACTOR_UNZIP_OK if there is no problem.
  */
 int
-EXTRACTOR_common_unzip_get_current_file_info (struct EXTRACTOR_UnzipFile * file,
-					      struct EXTRACTOR_UnzipFileInfo *pfile_info,
-					      char *szFileName,
-					      uLong fileNameBufferSize,
-					      void *extraField,
-					      uLong extraFieldBufferSize,
-					      char *szComment,
-					      uLong commentBufferSize)
+EXTRACTOR_common_unzip_get_current_file_info (struct EXTRACTOR_UnzipFile *file,
+                                              struct EXTRACTOR_UnzipFileInfo *
+                                              pfile_info,
+                                              char *szFileName,
+                                              uLong fileNameBufferSize,
+                                              void *extraField,
+                                              uLong extraFieldBufferSize,
+                                              char *szComment,
+                                              uLong commentBufferSize)
 {
   return get_current_file_info (file, pfile_info, NULL,
-				szFileName, fileNameBufferSize,
-				extraField, extraFieldBufferSize,
-				szComment, commentBufferSize);
+                                szFileName, fileNameBufferSize,
+                                extraField, extraFieldBufferSize,
+                                szComment, commentBufferSize);
 }
 
 
@@ -935,13 +940,15 @@ EXTRACTOR_common_unzip_go_to_next_file (struct EXTRACTOR_UnzipFile *file)
     return EXTRACTOR_UNZIP_END_OF_LIST_OF_FILE;
   if (file->num_file + 1 == file->gi.number_entry)
     return EXTRACTOR_UNZIP_END_OF_LIST_OF_FILE;
-  file->pos_in_central_dir += SIZECENTRALDIRITEM + file->cur_file_info.size_filename +
-    file->cur_file_info.size_file_extra + file->cur_file_info.size_file_comment;
+  file->pos_in_central_dir += SIZECENTRALDIRITEM
+                              + file->cur_file_info.size_filename
+                              + file->cur_file_info.size_file_extra
+                              + file->cur_file_info.size_file_comment;
   file->num_file++;
   err = get_current_file_info (file,
-			       &file->cur_file_info,
-			       &file->cur_file_info_internal,
-			       NULL, 0, NULL, 0, NULL, 0);
+                               &file->cur_file_info,
+                               &file->cur_file_info_internal,
+                               NULL, 0, NULL, 0, NULL, 0);
   file->current_file_ok = (EXTRACTOR_UNZIP_OK == err);
   return err;
 }
@@ -960,8 +967,8 @@ EXTRACTOR_common_unzip_go_to_next_file (struct EXTRACTOR_UnzipFile *file)
  */
 int
 EXTRACTOR_common_unzip_go_find_local_file (struct EXTRACTOR_UnzipFile *file,
-					   const char *szFileName,
-					   int iCaseSensitivity)
+                                           const char *szFileName,
+                                           int iCaseSensitivity)
 {
   int err;
   /* We remember the 'current' position in the file so that we can jump
@@ -987,22 +994,24 @@ EXTRACTOR_common_unzip_go_find_local_file (struct EXTRACTOR_UnzipFile *file,
   err = EXTRACTOR_common_unzip_go_to_first_file (file);
 
   while (EXTRACTOR_UNZIP_OK == err)
-    {
-      char szCurrentFileName[UNZ_MAXFILENAMEINZIP + 1];
+  {
+    char szCurrentFileName[UNZ_MAXFILENAMEINZIP + 1];
 
-      if (EXTRACTOR_UNZIP_OK !=
-	  (err = EXTRACTOR_common_unzip_get_current_file_info (file, NULL,
-							       szCurrentFileName,
-							       sizeof (szCurrentFileName) - 1,
-							       NULL, 0, NULL, 0)))
-	break;
-      if (0 ==
-	  EXTRACTOR_common_unzip_string_file_name_compare (szCurrentFileName,
-							   szFileName,
-							   iCaseSensitivity))
-	return EXTRACTOR_UNZIP_OK;
-      err = EXTRACTOR_common_unzip_go_to_next_file (file);
-    }
+    if (EXTRACTOR_UNZIP_OK !=
+        (err = EXTRACTOR_common_unzip_get_current_file_info (file, NULL,
+                                                             szCurrentFileName,
+                                                             sizeof (
+                                                               szCurrentFileName)
+                                                             - 1,
+                                                             NULL, 0, NULL, 0)))
+      break;
+    if (0 ==
+        EXTRACTOR_common_unzip_string_file_name_compare (szCurrentFileName,
+                                                         szFileName,
+                                                         iCaseSensitivity))
+      return EXTRACTOR_UNZIP_OK;
+    err = EXTRACTOR_common_unzip_go_to_next_file (file);
+  }
 
   /* We failed, so restore the state of the 'current file' to where we
    * were.
@@ -1027,8 +1036,8 @@ EXTRACTOR_common_unzip_go_find_local_file (struct EXTRACTOR_UnzipFile *file,
  */
 ssize_t
 EXTRACTOR_common_unzip_read_current_file (struct EXTRACTOR_UnzipFile *file,
-					  void *buf,
-					  size_t len)
+                                          void *buf,
+                                          size_t len)
 {
   int err = EXTRACTOR_UNZIP_OK;
   uInt iRead = 0;
@@ -1050,98 +1059,98 @@ EXTRACTOR_common_unzip_read_current_file (struct EXTRACTOR_UnzipFile *file,
       (uInt) pfile_in_zip_read_info->rest_read_uncompressed;
 
   while (pfile_in_zip_read_info->stream.avail_out > 0)
+  {
+    if ( (0 == pfile_in_zip_read_info->stream.avail_in) &&
+         (pfile_in_zip_read_info->rest_read_compressed > 0) )
     {
-      if ( (0 == pfile_in_zip_read_info->stream.avail_in) &&
-	   (pfile_in_zip_read_info->rest_read_compressed > 0) )
-        {
-	  uInt uReadThis = UNZ_BUFSIZE;
-	  if (pfile_in_zip_read_info->rest_read_compressed<uReadThis)
-	    uReadThis = (uInt) pfile_in_zip_read_info->rest_read_compressed;
-	  if (0 == uReadThis)
-	    return EXTRACTOR_UNZIP_EOF;
-	  if (0 !=
-	      ZSEEK (pfile_in_zip_read_info->z_filefunc,
-		     pfile_in_zip_read_info->pos_in_zipfile +
-		     pfile_in_zip_read_info->byte_before_the_zipfile,
-		     SEEK_SET))
-	    return EXTRACTOR_UNZIP_ERRNO;
-	  if (ZREAD (pfile_in_zip_read_info->z_filefunc,
-		     pfile_in_zip_read_info->read_buffer,
-		     uReadThis) != uReadThis)
-	    return EXTRACTOR_UNZIP_ERRNO;
+      uInt uReadThis = UNZ_BUFSIZE;
+      if (pfile_in_zip_read_info->rest_read_compressed<uReadThis)
+        uReadThis = (uInt) pfile_in_zip_read_info->rest_read_compressed;
+      if (0 == uReadThis)
+        return EXTRACTOR_UNZIP_EOF;
+      if (0 !=
+          ZSEEK (pfile_in_zip_read_info->z_filefunc,
+                 pfile_in_zip_read_info->pos_in_zipfile
+                 + pfile_in_zip_read_info->byte_before_the_zipfile,
+                 SEEK_SET))
+        return EXTRACTOR_UNZIP_ERRNO;
+      if (ZREAD (pfile_in_zip_read_info->z_filefunc,
+                 pfile_in_zip_read_info->read_buffer,
+                 uReadThis) != uReadThis)
+        return EXTRACTOR_UNZIP_ERRNO;
 
-	  pfile_in_zip_read_info->pos_in_zipfile += uReadThis;
-	  pfile_in_zip_read_info->rest_read_compressed -= uReadThis;
-	  pfile_in_zip_read_info->stream.next_in =
-	    (Bytef *) pfile_in_zip_read_info->read_buffer;
-	  pfile_in_zip_read_info->stream.avail_in = (uInt) uReadThis;
-        }
-
-      if (0 == pfile_in_zip_read_info->compression_method)
-	{
-	  uInt uDoCopy;
-
-	  if ( (0 == pfile_in_zip_read_info->stream.avail_in) &&
-	       (0 == pfile_in_zip_read_info->rest_read_compressed) )
-	    return (0 == iRead) ? EXTRACTOR_UNZIP_EOF : iRead;
-
-	  if (pfile_in_zip_read_info->stream.avail_out <
-	      pfile_in_zip_read_info->stream.avail_in)
-	    uDoCopy = pfile_in_zip_read_info->stream.avail_out;
-	  else
-	    uDoCopy = pfile_in_zip_read_info->stream.avail_in;
-	  memcpy (pfile_in_zip_read_info->stream.next_out,
-		  pfile_in_zip_read_info->stream.next_in,
-		  uDoCopy);
-	  pfile_in_zip_read_info->crc32 = crc32 (pfile_in_zip_read_info->crc32,
-						 pfile_in_zip_read_info->stream.next_out,
-						 uDoCopy);
-	  pfile_in_zip_read_info->rest_read_uncompressed -= uDoCopy;
-	  pfile_in_zip_read_info->stream.avail_in -= uDoCopy;
-	  pfile_in_zip_read_info->stream.avail_out -= uDoCopy;
-	  pfile_in_zip_read_info->stream.next_out += uDoCopy;
-	  pfile_in_zip_read_info->stream.next_in += uDoCopy;
-	  pfile_in_zip_read_info->stream.total_out += uDoCopy;
-	  iRead += uDoCopy;
-	}
-      else
-	{
-	  uLong uTotalOutBefore;
-	  uLong uTotalOutAfter;
-	  const Bytef *bufBefore;
-	  uLong uOutThis;
-	  int flush = Z_SYNC_FLUSH;
-
-	  uTotalOutBefore = pfile_in_zip_read_info->stream.total_out;
-	  bufBefore = pfile_in_zip_read_info->stream.next_out;
-
-	  /*
-	    if ((pfile_in_zip_read_info->rest_read_uncompressed ==
-	    pfile_in_zip_read_info->stream.avail_out) &&
-	    (pfile_in_zip_read_info->rest_read_compressed == 0))
-	    flush = Z_FINISH;
-	  */
-	  err = inflate (&pfile_in_zip_read_info->stream, flush);
-
-	  uTotalOutAfter = pfile_in_zip_read_info->stream.total_out;
-	  uOutThis = uTotalOutAfter-uTotalOutBefore;
-
-	  pfile_in_zip_read_info->crc32 =
-	    crc32 (pfile_in_zip_read_info->crc32, bufBefore,
-		   (uInt) (uOutThis));
-
-	  pfile_in_zip_read_info->rest_read_uncompressed -=
-	    uOutThis;
-
-	  iRead += (uInt) (uTotalOutAfter - uTotalOutBefore);
-
-	  if (Z_STREAM_END == err)
-	    return (0 == iRead) ? EXTRACTOR_UNZIP_EOF : iRead;
-	  if (Z_OK != err)
-	    break;
-	}
+      pfile_in_zip_read_info->pos_in_zipfile += uReadThis;
+      pfile_in_zip_read_info->rest_read_compressed -= uReadThis;
+      pfile_in_zip_read_info->stream.next_in =
+        (Bytef *) pfile_in_zip_read_info->read_buffer;
+      pfile_in_zip_read_info->stream.avail_in = (uInt) uReadThis;
     }
 
+    if (0 == pfile_in_zip_read_info->compression_method)
+    {
+      uInt uDoCopy;
+
+      if ( (0 == pfile_in_zip_read_info->stream.avail_in) &&
+           (0 == pfile_in_zip_read_info->rest_read_compressed) )
+        return (0 == iRead) ? EXTRACTOR_UNZIP_EOF : iRead;
+
+      if (pfile_in_zip_read_info->stream.avail_out <
+          pfile_in_zip_read_info->stream.avail_in)
+        uDoCopy = pfile_in_zip_read_info->stream.avail_out;
+      else
+        uDoCopy = pfile_in_zip_read_info->stream.avail_in;
+      memcpy (pfile_in_zip_read_info->stream.next_out,
+              pfile_in_zip_read_info->stream.next_in,
+              uDoCopy);
+      pfile_in_zip_read_info->crc32 = crc32 (pfile_in_zip_read_info->crc32,
+                                             pfile_in_zip_read_info->stream.
+                                             next_out,
+                                             uDoCopy);
+      pfile_in_zip_read_info->rest_read_uncompressed -= uDoCopy;
+      pfile_in_zip_read_info->stream.avail_in -= uDoCopy;
+      pfile_in_zip_read_info->stream.avail_out -= uDoCopy;
+      pfile_in_zip_read_info->stream.next_out += uDoCopy;
+      pfile_in_zip_read_info->stream.next_in += uDoCopy;
+      pfile_in_zip_read_info->stream.total_out += uDoCopy;
+      iRead += uDoCopy;
+    }
+    else
+    {
+      uLong uTotalOutBefore;
+      uLong uTotalOutAfter;
+      const Bytef *bufBefore;
+      uLong uOutThis;
+      int flush = Z_SYNC_FLUSH;
+
+      uTotalOutBefore = pfile_in_zip_read_info->stream.total_out;
+      bufBefore = pfile_in_zip_read_info->stream.next_out;
+
+      /*
+        if ((pfile_in_zip_read_info->rest_read_uncompressed ==
+        pfile_in_zip_read_info->stream.avail_out) &&
+        (pfile_in_zip_read_info->rest_read_compressed == 0))
+        flush = Z_FINISH;
+      */err = inflate (&pfile_in_zip_read_info->stream, flush);
+
+      uTotalOutAfter = pfile_in_zip_read_info->stream.total_out;
+      uOutThis = uTotalOutAfter - uTotalOutBefore;
+
+      pfile_in_zip_read_info->crc32 =
+        crc32 (pfile_in_zip_read_info->crc32, bufBefore,
+               (uInt) (uOutThis));
+
+      pfile_in_zip_read_info->rest_read_uncompressed -=
+        uOutThis;
+
+      iRead += (uInt) (uTotalOutAfter - uTotalOutBefore);
+
+      if (Z_STREAM_END == err)
+        return (0 == iRead) ? EXTRACTOR_UNZIP_EOF : iRead;
+      if (Z_OK != err)
+        break;
+    }
+  }
+
   if (Z_OK == err)
     return iRead;
   return err;
@@ -1162,9 +1171,9 @@ EXTRACTOR_common_unzip_read_current_file (struct EXTRACTOR_UnzipFile *file,
  */
 static int
 parse_current_file_coherency_header (struct EXTRACTOR_UnzipFile *file,
-				     uInt *piSizeVar,
-				     uLong *poffset_local_extrafield,
-				     uInt *psize_local_extrafield)
+                                     uInt *piSizeVar,
+                                     uLong *poffset_local_extrafield,
+                                     uInt *psize_local_extrafield)
 {
   uLong uMagic;
   uLong uData;
@@ -1177,20 +1186,20 @@ parse_current_file_coherency_header (struct EXTRACTOR_UnzipFile *file,
   *psize_local_extrafield = 0;
 
   if (0 != ZSEEK (file->z_filefunc,
-		  file->cur_file_info_internal.offset_curfile +
-		  file->byte_before_the_zipfile,
-		  SEEK_SET))
+                  file->cur_file_info_internal.offset_curfile
+                  + file->byte_before_the_zipfile,
+                  SEEK_SET))
     return EXTRACTOR_UNZIP_ERRNO;
   if (EXTRACTOR_UNZIP_OK !=
       read_long_from_ffd (&file->z_filefunc,
-			  &uMagic))
+                          &uMagic))
     return EXTRACTOR_UNZIP_ERRNO;
   if (0x04034b50 != uMagic)
     return EXTRACTOR_UNZIP_BADZIPFILE;
   if ( (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd (&file->z_filefunc, &uData)) ||
+        read_short_from_ffd (&file->z_filefunc, &uData)) ||
        (EXTRACTOR_UNZIP_OK !=
-	read_short_from_ffd (&file->z_filefunc, &uFlags)) )
+        read_short_from_ffd (&file->z_filefunc, &uFlags)) )
     return EXTRACTOR_UNZIP_ERRNO;
   if (EXTRACTOR_UNZIP_OK != read_short_from_ffd (&file->z_filefunc, &uData))
     return EXTRACTOR_UNZIP_ERRNO;
@@ -1209,14 +1218,14 @@ parse_current_file_coherency_header (struct EXTRACTOR_UnzipFile *file,
        (0 == (uFlags & 8)) )
     return EXTRACTOR_UNZIP_BADZIPFILE;
   if (EXTRACTOR_UNZIP_OK !=
-      read_long_from_ffd(&file->z_filefunc, &uData)) /* size compr */
+      read_long_from_ffd (&file->z_filefunc, &uData)) /* size compr */
     return EXTRACTOR_UNZIP_ERRNO;
   if ( (uData != file->cur_file_info.compressed_size) &&
        (0 == (uFlags & 8)) )
     return EXTRACTOR_UNZIP_BADZIPFILE;
   if (EXTRACTOR_UNZIP_OK !=
       read_long_from_ffd (&file->z_filefunc,
-			  &uData)) /* size uncompr */
+                          &uData)) /* size uncompr */
     return EXTRACTOR_UNZIP_ERRNO;
   if ( (uData != file->cur_file_info.uncompressed_size) &&
        (0 == (uFlags & 8)))
@@ -1229,12 +1238,12 @@ parse_current_file_coherency_header (struct EXTRACTOR_UnzipFile *file,
   *piSizeVar += (uInt) size_filename;
   if (EXTRACTOR_UNZIP_OK !=
       read_short_from_ffd (&file->z_filefunc,
-			   &size_extra_field))
+                           &size_extra_field))
     return EXTRACTOR_UNZIP_ERRNO;
-  *poffset_local_extrafield = file->cur_file_info_internal.offset_curfile +
-    SIZEZIPLOCALHEADER + size_filename;
+  *poffset_local_extrafield = file->cur_file_info_internal.offset_curfile
+                              + SIZEZIPLOCALHEADER + size_filename;
   *psize_local_extrafield = (uInt) size_extra_field;
-  *piSizeVar += (uInt)size_extra_field;
+  *piSizeVar += (uInt) size_extra_field;
 
   return EXTRACTOR_UNZIP_OK;
 }
@@ -1253,7 +1262,7 @@ EXTRACTOR_common_unzip_open_current_file (struct EXTRACTOR_UnzipFile *file)
   uInt iSizeVar;
   struct FileInZipReadInfo *pfile_in_zip_read_info;
   uLong offset_local_extrafield;  /* offset of the local extra field */
-  uInt  size_local_extrafield;    /* size of the local extra field */
+  uInt size_local_extrafield;     /* size of the local extra field */
 
   if (NULL == file)
     return EXTRACTOR_UNZIP_PARAMERROR;
@@ -1263,17 +1272,18 @@ EXTRACTOR_common_unzip_open_current_file (struct EXTRACTOR_UnzipFile *file)
     EXTRACTOR_common_unzip_close_current_file (file);
   if (EXTRACTOR_UNZIP_OK !=
       parse_current_file_coherency_header (file,
-					   &iSizeVar,
-					   &offset_local_extrafield,
-					   &size_local_extrafield))
+                                           &iSizeVar,
+                                           &offset_local_extrafield,
+                                           &size_local_extrafield))
     return EXTRACTOR_UNZIP_BADZIPFILE;
-  if (NULL == (pfile_in_zip_read_info = malloc (sizeof(struct FileInZipReadInfo))))
+  if (NULL == (pfile_in_zip_read_info = malloc (sizeof(struct
+                                                       FileInZipReadInfo))))
     return EXTRACTOR_UNZIP_INTERNALERROR;
   if (NULL == (pfile_in_zip_read_info->read_buffer = malloc (UNZ_BUFSIZE)))
-    {
-      free (pfile_in_zip_read_info);
-      return EXTRACTOR_UNZIP_INTERNALERROR;
-    }
+  {
+    free (pfile_in_zip_read_info);
+    return EXTRACTOR_UNZIP_INTERNALERROR;
+  }
   pfile_in_zip_read_info->offset_local_extrafield = offset_local_extrafield;
   pfile_in_zip_read_info->size_local_extrafield = size_local_extrafield;
   pfile_in_zip_read_info->pos_local_extrafield = 0;
@@ -1281,45 +1291,49 @@ EXTRACTOR_common_unzip_open_current_file (struct EXTRACTOR_UnzipFile *file)
 
   if ( (0 != file->cur_file_info.compression_method) &&
        (Z_DEFLATED != file->cur_file_info.compression_method) )
-    {
-      // err = EXTRACTOR_UNZIP_BADZIPFILE;
-      // FIXME: we don't do anything with this 'err' code.
-      // Can this happen? Should we abort in this case?
-    }
+  {
+    // err = EXTRACTOR_UNZIP_BADZIPFILE;
+    // FIXME: we don't do anything with this 'err' code.
+    // Can this happen? Should we abort in this case?
+  }
 
   pfile_in_zip_read_info->crc32_wait = file->cur_file_info.crc;
   pfile_in_zip_read_info->crc32 = 0;
-  pfile_in_zip_read_info->compression_method = file->cur_file_info.compression_method;
+  pfile_in_zip_read_info->compression_method =
+    file->cur_file_info.compression_method;
   pfile_in_zip_read_info->z_filefunc = file->z_filefunc;
-  pfile_in_zip_read_info->byte_before_the_zipfile = file->byte_before_the_zipfile;
+  pfile_in_zip_read_info->byte_before_the_zipfile =
+    file->byte_before_the_zipfile;
   pfile_in_zip_read_info->stream.total_out = 0;
   if (Z_DEFLATED == file->cur_file_info.compression_method)
+  {
+    pfile_in_zip_read_info->stream.zalloc = (alloc_func) NULL;
+    pfile_in_zip_read_info->stream.zfree = (free_func) NULL;
+    pfile_in_zip_read_info->stream.opaque = NULL;
+    pfile_in_zip_read_info->stream.next_in = NULL;
+    pfile_in_zip_read_info->stream.avail_in = 0;
+    if (Z_OK != (err = inflateInit2 (&pfile_in_zip_read_info->stream,
+                                     -MAX_WBITS)))
     {
-      pfile_in_zip_read_info->stream.zalloc = (alloc_func) NULL;
-      pfile_in_zip_read_info->stream.zfree = (free_func) NULL;
-      pfile_in_zip_read_info->stream.opaque = NULL;
-      pfile_in_zip_read_info->stream.next_in = NULL;
-      pfile_in_zip_read_info->stream.avail_in = 0;
-      if (Z_OK != (err = inflateInit2 (&pfile_in_zip_read_info->stream, -MAX_WBITS)))
-	{
-	  free (pfile_in_zip_read_info->read_buffer);
-	  free (pfile_in_zip_read_info);
-	  return err;
-	}
-      pfile_in_zip_read_info->stream_initialised = 1;
-      /* windowBits is passed < 0 to tell that there is no zlib header.
-       * Note that in this case inflate *requires* an extra "dummy" byte
-       * after the compressed stream in order to complete decompression and
-       * return Z_STREAM_END.
-       * In unzip, i don't wait absolutely Z_STREAM_END because I known the
-       * size of both compressed and uncompressed data
-       */
+      free (pfile_in_zip_read_info->read_buffer);
+      free (pfile_in_zip_read_info);
+      return err;
     }
-  pfile_in_zip_read_info->rest_read_compressed = file->cur_file_info.compressed_size;
-  pfile_in_zip_read_info->rest_read_uncompressed = file->cur_file_info.uncompressed_size;
+    pfile_in_zip_read_info->stream_initialised = 1;
+    /* windowBits is passed < 0 to tell that there is no zlib header.
+     * Note that in this case inflate *requires* an extra "dummy" byte
+     * after the compressed stream in order to complete decompression and
+     * return Z_STREAM_END.
+     * In unzip, i don't wait absolutely Z_STREAM_END because I known the
+     * size of both compressed and uncompressed data
+     */}
+  pfile_in_zip_read_info->rest_read_compressed =
+    file->cur_file_info.compressed_size;
+  pfile_in_zip_read_info->rest_read_uncompressed =
+    file->cur_file_info.uncompressed_size;
   pfile_in_zip_read_info->pos_in_zipfile =
-    file->cur_file_info_internal.offset_curfile + SIZEZIPLOCALHEADER +
-    iSizeVar;
+    file->cur_file_info_internal.offset_curfile + SIZEZIPLOCALHEADER
+    + iSizeVar;
   pfile_in_zip_read_info->stream.avail_in = 0;
   file->pfile_in_zip_read = pfile_in_zip_read_info;
   return EXTRACTOR_UNZIP_OK;
@@ -1337,8 +1351,8 @@ EXTRACTOR_common_unzip_open_current_file (struct EXTRACTOR_UnzipFile *file)
  */
 static uLong
 ec_read_file_func (voidpf opaque,
-		   void* buf,
-		   uLong size)
+                   void*buf,
+                   uLong size)
 {
   struct EXTRACTOR_ExtractContext *ec = opaque;
   void *ptr;
@@ -1347,15 +1361,15 @@ ec_read_file_func (voidpf opaque,
 
   done = 0;
   while (done < size)
-    {
-      ret = ec->read (ec->cls,
-		      &ptr,
-		      size - done);
-      if (ret <= 0)
-	return done;
-      memcpy (buf + done, ptr, ret);
-      done += ret;
-    }
+  {
+    ret = ec->read (ec->cls,
+                    &ptr,
+                    size - done);
+    if (ret <= 0)
+      return done;
+    memcpy (buf + done, ptr, ret);
+    done += ret;
+  }
   return done;
 }
 
@@ -1385,8 +1399,8 @@ ec_tell_file_func (voidpf opaque)
  */
 static long
 ec_seek_file_func (voidpf opaque,
-		   uLong offset,
-		   int origin)
+                   uLong offset,
+                   int origin)
 {
   struct EXTRACTOR_ExtractContext *ec = opaque;
 
@@ -1416,4 +1430,5 @@ EXTRACTOR_common_unzip_open (struct EXTRACTOR_ExtractContext *ec)
   return unzip_open_using_ffd (&ffd);
 }
 
+
 /* end of unzip.c */
