@@ -71,9 +71,9 @@ struct PluginReplyProcessor
  */
 static void
 send_update_message (struct EXTRACTOR_PluginList *plugin,
-		     int64_t shm_off,
-		     size_t data_available,
-		     struct EXTRACTOR_Datasource *ds)
+                     int64_t shm_off,
+                     size_t data_available,
+                     struct EXTRACTOR_Datasource *ds)
 {
   struct UpdateMessage um;
 
@@ -85,14 +85,14 @@ send_update_message (struct EXTRACTOR_PluginList *plugin,
   um.file_size = EXTRACTOR_datasource_get_size_ (ds, 0);
   if (sizeof (um) !=
       EXTRACTOR_IPC_channel_send_ (plugin->channel,
-				   &um,
-				   sizeof (um)) )
-    {
-      LOG ("Failed to send UPDATED_SHM message to plugin\n");
-      EXTRACTOR_IPC_channel_destroy_ (plugin->channel);
-      plugin->channel = NULL;
-      plugin->round_finished = 1;
-    }
+                                   &um,
+                                   sizeof (um)) )
+  {
+    LOG ("Failed to send UPDATED_SHM message to plugin\n");
+    EXTRACTOR_IPC_channel_destroy_ (plugin->channel);
+    plugin->channel = NULL;
+    plugin->round_finished = 1;
+  }
 }
 
 
@@ -109,14 +109,14 @@ send_discard_message (struct EXTRACTOR_PluginList *plugin)
 
   if (sizeof (disc_msg) !=
       EXTRACTOR_IPC_channel_send_ (plugin->channel,
-				   &disc_msg,
-				   sizeof (disc_msg)) )
-    {
-      LOG ("Failed to send DISCARD_STATE message to plugin\n");
-      EXTRACTOR_IPC_channel_destroy_ (plugin->channel);
-      plugin->channel = NULL;
-      plugin->round_finished = 1;
-    }
+                                   &disc_msg,
+                                   sizeof (disc_msg)) )
+  {
+    LOG ("Failed to send DISCARD_STATE message to plugin\n");
+    EXTRACTOR_IPC_channel_destroy_ (plugin->channel);
+    plugin->channel = NULL;
+    plugin->round_finished = 1;
+  }
 }
 
 
@@ -131,12 +131,12 @@ abort_all_channels (struct EXTRACTOR_PluginList *plugins)
   struct EXTRACTOR_PluginList *pos;
 
   for (pos = plugins; NULL != pos; pos = pos->next)
-    {
-      if (NULL == pos->channel)
-	continue;
-      EXTRACTOR_IPC_channel_destroy_ (pos->channel);
-      pos->channel = NULL;
-    }
+  {
+    if (NULL == pos->channel)
+      continue;
+    EXTRACTOR_IPC_channel_destroy_ (pos->channel);
+    pos->channel = NULL;
+  }
 }
 
 
@@ -153,46 +153,46 @@ abort_all_channels (struct EXTRACTOR_PluginList *plugins)
  */
 static void
 process_plugin_reply (void *cls,
-		      struct EXTRACTOR_PluginList *plugin,
-		      enum EXTRACTOR_MetaType meta_type,
-		      enum EXTRACTOR_MetaFormat meta_format,
-		      const char *mime,
-		      const void *value,
+                      struct EXTRACTOR_PluginList *plugin,
+                      enum EXTRACTOR_MetaType meta_type,
+                      enum EXTRACTOR_MetaFormat meta_format,
+                      const char *mime,
+                      const void *value,
                       size_t value_len)
 {
   static unsigned char cont_msg = MESSAGE_CONTINUE_EXTRACTING;
   struct PluginReplyProcessor *prp = cls;
 
   if (0 != prp->file_finished)
-    {
-      /* client already aborted, ignore message, tell plugin about abort */
-      return;
-    }
+  {
+    /* client already aborted, ignore message, tell plugin about abort */
+    return;
+  }
   if (0 != prp->proc (prp->proc_cls,
-		      plugin->short_libname,
-		      meta_type,
-		      meta_format,
-		      mime,
-		      value,
-		      value_len))
-    {
-      prp->file_finished = 1;
+                      plugin->short_libname,
+                      meta_type,
+                      meta_format,
+                      mime,
+                      value,
+                      value_len))
+  {
+    prp->file_finished = 1;
 #if DEBUG
-      fprintf (stderr, "Sending ABRT\n");
+    fprintf (stderr, "Sending ABRT\n");
 #endif
-      send_discard_message (plugin);
-      return;
-    }
+    send_discard_message (plugin);
+    return;
+  }
   if (sizeof (cont_msg) !=
       EXTRACTOR_IPC_channel_send_ (plugin->channel,
-				   &cont_msg,
-				   sizeof (cont_msg)) )
-    {
-      LOG ("Failed to send CONTINUE_EXTRACTING message to plugin\n");
-      EXTRACTOR_IPC_channel_destroy_ (plugin->channel);
-      plugin->channel = NULL;
-      plugin->round_finished = 1;
-    }
+                                   &cont_msg,
+                                   sizeof (cont_msg)) )
+  {
+    LOG ("Failed to send CONTINUE_EXTRACTING message to plugin\n");
+    EXTRACTOR_IPC_channel_destroy_ (plugin->channel);
+    plugin->channel = NULL;
+    plugin->round_finished = 1;
+  }
 }
 
 
@@ -245,8 +245,8 @@ struct InProcessContext
  */
 static ssize_t
 in_process_read (void *cls,
-		 void **data,
-		 size_t size)
+                 void **data,
+                 size_t size)
 {
   struct InProcessContext *ctx = cls;
   ssize_t ret;
@@ -256,8 +256,8 @@ in_process_read (void *cls,
   if (size < bsize)
     bsize = size;
   ret = EXTRACTOR_datasource_read_ (ctx->ds,
-				    ctx->buf,
-				    bsize);
+                                    ctx->buf,
+                                    bsize);
   if (-1 == ret)
     *data = NULL;
   else
@@ -279,14 +279,14 @@ in_process_read (void *cls,
  */
 static int64_t
 in_process_seek (void *cls,
-		 int64_t pos,
-		 int whence)
+                 int64_t pos,
+                 int whence)
 {
   struct InProcessContext *ctx = cls;
 
   return EXTRACTOR_datasource_seek_ (ctx->ds,
-				     pos,
-				     whence);
+                                     pos,
+                                     whence);
 }
 
 
@@ -326,12 +326,12 @@ in_process_get_size (void *cls)
  */
 static int
 in_process_proc (void *cls,
-		 const char *plugin_name,
-		 enum EXTRACTOR_MetaType type,
-		 enum EXTRACTOR_MetaFormat format,
-		 const char *data_mime_type,
-		 const char *data,
-		 size_t data_len)
+                 const char *plugin_name,
+                 enum EXTRACTOR_MetaType type,
+                 enum EXTRACTOR_MetaFormat format,
+                 const char *data_mime_type,
+                 const char *data,
+                 size_t data_len)
 {
   struct InProcessContext *ctx = cls;
   int ret;
@@ -339,12 +339,12 @@ in_process_proc (void *cls,
   if (0 != ctx->finished)
     return 1;
   ret = ctx->proc (ctx->proc_cls,
-		   plugin_name,
-		   type,
-		   format,
-		   data_mime_type,
-		   data,
-		   data_len);
+                   plugin_name,
+                   type,
+                   format,
+                   data_mime_type,
+                   data,
+                   data_len);
   if (0 != ret)
     ctx->finished = 1;
   return ret;
@@ -363,9 +363,9 @@ in_process_proc (void *cls,
  */
 static void
 do_extract (struct EXTRACTOR_PluginList *plugins,
-	    struct EXTRACTOR_SharedMemory *shm,
-	    struct EXTRACTOR_Datasource *ds,
-	    EXTRACTOR_MetaDataProcessor proc, void *proc_cls)
+            struct EXTRACTOR_SharedMemory *shm,
+            struct EXTRACTOR_Datasource *ds,
+            EXTRACTOR_MetaDataProcessor proc, void *proc_cls)
 {
   unsigned int plugin_count;
   unsigned int plugin_off;
@@ -406,153 +406,147 @@ do_extract (struct EXTRACTOR_PluginList *plugins,
   start.shm_ready_bytes = (uint32_t) ready;
   start.file_size = EXTRACTOR_datasource_get_size_ (ds, 0);
   for (pos = plugins; NULL != pos; pos = pos->next)
+  {
+    if (EXTRACTOR_OPTION_IN_PROCESS == pos->flags)
+      have_in_memory = 1;
+    if ( (NULL != pos->channel) &&
+         (-1 == EXTRACTOR_IPC_channel_send_ (pos->channel,
+                                             &start,
+                                             sizeof (start)) ) )
     {
-      if (EXTRACTOR_OPTION_IN_PROCESS == pos->flags)
-	have_in_memory = 1;
-      if ( (NULL != pos->channel) &&
-	   (-1 == EXTRACTOR_IPC_channel_send_ (pos->channel,
-					       &start,
-					       sizeof (start)) ) )
-	{
-	  LOG ("Failed to send EXTRACT_START message to plugin\n");
-	  EXTRACTOR_IPC_channel_destroy_ (pos->channel);
-	  pos->channel = NULL;
-	}
+      LOG ("Failed to send EXTRACT_START message to plugin\n");
+      EXTRACTOR_IPC_channel_destroy_ (pos->channel);
+      pos->channel = NULL;
     }
-  if (-1 == ready)
-    {
-      LOG ("Failed to initialize IPC shared memory, cannot extract\n");
-      done = 1;
-    }
-  else
-    done = 0;
+  }
+  done = 0;
   while (! done)
+  {
+    struct EXTRACTOR_Channel *channels[plugin_count];
+
+    /* calculate current 'channels' array */
+    plugin_off = 0;
+    for (pos = plugins; NULL != pos; pos = pos->next)
     {
-      struct EXTRACTOR_Channel *channels[plugin_count];
-
-      /* calculate current 'channels' array */
-      plugin_off = 0;
-      for (pos = plugins; NULL != pos; pos = pos->next)
-	{
-	  if (-1 == pos->seek_request)
-	    {
-	      /* channel is not seeking, must be running or done */
-	      channels[plugin_off] = pos->channel;
-	    }
-	  else
-	    {
-	      /* not running this round, seeking! */
-	      channels[plugin_off] = NULL;
-	    }
-	  plugin_off++;
-	}
-      /* give plugins chance to send us meta data, seek or finished messages */
-      if (-1 ==
-	  EXTRACTOR_IPC_channel_recv_ (channels,
-				       plugin_count,
-				       &process_plugin_reply,
-				       &prp))
-	{
-	  /* serious problem in IPC; reset *all* channels */
-	  LOG ("Failed to receive message from channels; full reset\n");
-	  abort_all_channels (plugins);
-	  break;
-	}
-
-      /* calculate minimum seek request (or set done=0 to continue here) */
-      done = 1;
-      min_seek = -1;
-      plugin_off = 0;
-      for (pos = plugins; NULL != pos; pos = pos->next)
-	{
-	  plugin_off++;
-	  if ( (1 == pos->round_finished) ||
-	       (NULL == pos->channel) )
-          {
-            continue; /* inactive plugin */
-          }
-	  if (-1 == pos->seek_request)
-	    {
-	      /* possibly more meta data at current position, at least
-		 this plugin is still working on it... */
-	      done = 0;
-	      break;
-	    }
-	  if (-1 != pos->seek_request)
-	    {
-	      if (SEEK_END == pos->seek_whence)
-		{
-		  /* convert distance from end to absolute position */
-		  pos->seek_whence = 0;
-		  end = EXTRACTOR_datasource_get_size_ (ds, 1);
-		  if (pos->seek_request > end)
-		    {
-		      LOG ("Cannot seek to before the beginning of the file!\n");
-		      pos->seek_request = 0;
-		    }
-		  else
-		    {
-		      pos->seek_request = end - pos->seek_request;
-		    }
-		}
-	      if ( (-1 == min_seek) ||
-		   (min_seek > pos->seek_request) )
-		{
-		  min_seek = pos->seek_request;
-		}
-	    }
-	}
-      data_available = -1;
-      if ( (1 == done) &&
-	   (-1 != min_seek) &&
-           (NULL != shm) )
-	{
-	  /* current position done, but seek requested */
-	  done = 0;
-	  if (-1 ==
-	      (data_available = EXTRACTOR_IPC_shared_memory_set_ (shm,
-								  ds,
-								  min_seek,
-								  DEFAULT_SHM_SIZE)))
-	    {
-	      LOG ("Failed to seek; full reset\n");
-	      abort_all_channels (plugins);
-	      break;
-	    }
-	}
-      /* if 'prp.file_finished', send 'abort' to plugins;
-	 if not, send 'seek' notification to plugins in range */
-      for (pos = plugins; NULL != pos; pos = pos->next)
-	{
-	  if (NULL == (channel = pos->channel))
-	    {
-	      /* Skipping plugin: channel down */
-	      continue;
-	    }
-	  if ( (-1 != pos->seek_request) &&
-	       (1 == prp.file_finished) )
-	    {
-	      send_discard_message (pos);
-	      pos->round_finished = 1;
-	      pos->seek_request = -1;
-	    }
-	  if ( (-1 != data_available) &&
-	       (-1 != pos->seek_request) &&
-	       (min_seek <= pos->seek_request) &&
-	       ( (min_seek + data_available > pos->seek_request) ||
-		 (min_seek == EXTRACTOR_datasource_get_size_ (ds, 0))) )
-	    {
-	      /* Notify plugin about seek to 'min_seek' */
-	      send_update_message (pos,
-				   min_seek,
-				   data_available,
-				   ds);
-	      pos->seek_request = -1;
-	    }
-	  if (0 == pos->round_finished)
-	    done = 0; /* can't be done, plugin still active */
-	}
+      if (-1 == pos->seek_request)
+      {
+        /* channel is not seeking, must be running or done */
+        channels[plugin_off] = pos->channel;
+      }
+      else
+      {
+        /* not running this round, seeking! */
+        channels[plugin_off] = NULL;
+      }
+      plugin_off++;
     }
+    /* give plugins chance to send us meta data, seek or finished messages */
+    if (-1 ==
+        EXTRACTOR_IPC_channel_recv_ (channels,
+                                     plugin_count,
+                                     &process_plugin_reply,
+                                     &prp))
+    {
+      /* serious problem in IPC; reset *all* channels */
+      LOG ("Failed to receive message from channels; full reset\n");
+      abort_all_channels (plugins);
+      break;
+    }
+
+    /* calculate minimum seek request (or set done=0 to continue here) */
+    done = 1;
+    min_seek = -1;
+    plugin_off = 0;
+    for (pos = plugins; NULL != pos; pos = pos->next)
+    {
+      plugin_off++;
+      if ( (1 == pos->round_finished) ||
+           (NULL == pos->channel) )
+      {
+        continue;     /* inactive plugin */
+      }
+      if (-1 == pos->seek_request)
+      {
+        /* possibly more meta data at current position, at least
+     this plugin is still working on it... */
+        done = 0;
+        break;
+      }
+      if (-1 != pos->seek_request)
+      {
+        if (SEEK_END == pos->seek_whence)
+        {
+          /* convert distance from end to absolute position */
+          pos->seek_whence = 0;
+          end = EXTRACTOR_datasource_get_size_ (ds, 1);
+          if (pos->seek_request > end)
+          {
+            LOG ("Cannot seek to before the beginning of the file!\n");
+            pos->seek_request = 0;
+          }
+          else
+          {
+            pos->seek_request = end - pos->seek_request;
+          }
+        }
+        if ( (-1 == min_seek) ||
+             (min_seek > pos->seek_request) )
+        {
+          min_seek = pos->seek_request;
+        }
+      }
+    }
+    data_available = -1;
+    if ( (1 == done) &&
+         (-1 != min_seek) &&
+         (NULL != shm) )
+    {
+      /* current position done, but seek requested */
+      done = 0;
+      if (-1 ==
+          (data_available = EXTRACTOR_IPC_shared_memory_set_ (shm,
+                                                              ds,
+                                                              min_seek,
+                                                              DEFAULT_SHM_SIZE)))
+      {
+        LOG ("Failed to seek; full reset\n");
+        abort_all_channels (plugins);
+        break;
+      }
+    }
+    /* if 'prp.file_finished', send 'abort' to plugins;
+       if not, send 'seek' notification to plugins in range */
+    for (pos = plugins; NULL != pos; pos = pos->next)
+    {
+      if (NULL == (channel = pos->channel))
+      {
+        /* Skipping plugin: channel down */
+        continue;
+      }
+      if ( (-1 != pos->seek_request) &&
+           (1 == prp.file_finished) )
+      {
+        send_discard_message (pos);
+        pos->round_finished = 1;
+        pos->seek_request = -1;
+      }
+      if ( (-1 != data_available) &&
+           (-1 != pos->seek_request) &&
+           (min_seek <= pos->seek_request) &&
+           ( (min_seek + data_available > pos->seek_request) ||
+             (min_seek == EXTRACTOR_datasource_get_size_ (ds, 0))) )
+      {
+        /* Notify plugin about seek to 'min_seek' */
+        send_update_message (pos,
+                             min_seek,
+                             data_available,
+                             ds);
+        pos->seek_request = -1;
+      }
+      if (0 == pos->round_finished)
+        done = 0; /* can't be done, plugin still active */
+    }
+  }
 
   if (0 == have_in_memory)
     return;
@@ -567,22 +561,22 @@ do_extract (struct EXTRACTOR_PluginList *plugins,
   ec.get_size = &in_process_get_size;
   ec.proc = &in_process_proc;
   for (pos = plugins; NULL != pos; pos = pos->next)
+  {
+    if (EXTRACTOR_OPTION_IN_PROCESS != pos->flags)
+      continue;
+    if (-1 == EXTRACTOR_plugin_load_ (pos))
+      continue;
+    ctx.plugin = pos;
+    ec.config = pos->plugin_options;
+    if (-1 == EXTRACTOR_datasource_seek_ (ds, 0, SEEK_SET))
     {
-      if (EXTRACTOR_OPTION_IN_PROCESS != pos->flags)
-	continue;
-      if (-1 == EXTRACTOR_plugin_load_ (pos))
-        continue;
-      ctx.plugin = pos;
-      ec.config = pos->plugin_options;
-      if (-1 == EXTRACTOR_datasource_seek_ (ds, 0, SEEK_SET))
-	{
-	  LOG ("Failed to seek to 0 for in-memory plugins\n");
-	  return;
-	}
-      pos->extract_method (&ec);
-      if (1 == ctx.finished)
-	break;
+      LOG ("Failed to seek to 0 for in-memory plugins\n");
+      return;
     }
+    pos->extract_method (&ec);
+    if (1 == ctx.finished)
+      break;
+  }
 }
 
 
@@ -602,11 +596,11 @@ do_extract (struct EXTRACTOR_PluginList *plugins,
  */
 void
 EXTRACTOR_extract (struct EXTRACTOR_PluginList *plugins,
-		   const char *filename,
-		   const void *data,
-		   size_t size,
-		   EXTRACTOR_MetaDataProcessor proc,
-		   void *proc_cls)
+                   const char *filename,
+                   const void *data,
+                   size_t size,
+                   EXTRACTOR_MetaDataProcessor proc,
+                   void *proc_cls)
 {
   struct EXTRACTOR_Datasource *datasource;
   struct EXTRACTOR_SharedMemory *shm;
@@ -617,47 +611,47 @@ EXTRACTOR_extract (struct EXTRACTOR_PluginList *plugins,
     return;
   if (NULL == filename)
     datasource = EXTRACTOR_datasource_create_from_buffer_ (data, size,
-							   proc, proc_cls);
+                                                           proc, proc_cls);
   else
     datasource = EXTRACTOR_datasource_create_from_file_ (filename,
-							 proc, proc_cls);
+                                                         proc, proc_cls);
   if (NULL == datasource)
     return;
   shm = NULL;
   have_oop = 0;
   for (pos = plugins; NULL != pos; pos = pos->next)
-    {
-      if (NULL == shm)
-	shm = pos->shm;
-      if (EXTRACTOR_OPTION_IN_PROCESS != pos->flags)
-	have_oop = 1;
-      pos->round_finished = 0;
-    }
+  {
+    if (NULL == shm)
+      shm = pos->shm;
+    if (EXTRACTOR_OPTION_IN_PROCESS != pos->flags)
+      have_oop = 1;
+    pos->round_finished = 0;
+  }
   if ( (NULL == shm) &&
        (1 == have_oop) )
+  {
+    /* need to create shared memory segment */
+    shm = EXTRACTOR_IPC_shared_memory_create_ (DEFAULT_SHM_SIZE);
+    if (NULL == shm)
     {
-      /* need to create shared memory segment */
-      shm = EXTRACTOR_IPC_shared_memory_create_ (DEFAULT_SHM_SIZE);
-      if (NULL == shm)
-	{
-	  LOG ("Failed to setup IPC\n");
-	  EXTRACTOR_datasource_destroy_ (datasource);
-	  return;
-	}
+      LOG ("Failed to setup IPC\n");
+      EXTRACTOR_datasource_destroy_ (datasource);
+      return;
     }
+  }
   for (pos = plugins; NULL != pos; pos = pos->next)
     if ( (NULL == pos->channel) &&
          (NULL != shm) &&
-	 (EXTRACTOR_OPTION_IN_PROCESS != pos->flags) )
+         (EXTRACTOR_OPTION_IN_PROCESS != pos->flags) )
+    {
+      if (NULL == pos->shm)
       {
-	if (NULL == pos->shm)
-	  {
-	    pos->shm = shm;
-	    (void) EXTRACTOR_IPC_shared_memory_change_rc_ (shm, 1);
-	  }
-	pos->channel = EXTRACTOR_IPC_channel_create_ (pos,
-						      shm);
+        pos->shm = shm;
+        (void) EXTRACTOR_IPC_shared_memory_change_rc_ (shm, 1);
       }
+      pos->channel = EXTRACTOR_IPC_channel_create_ (pos,
+                                                    shm);
+    }
   do_extract (plugins,
               shm,
               datasource,
@@ -680,14 +674,14 @@ EXTRACTOR_ltdl_init ()
 #endif
   err = lt_dlinit ();
   if (err > 0)
-    {
+  {
 #if DEBUG
-      fprintf (stderr,
-	       _("Initialization of plugin mechanism failed: %s!\n"),
-	       lt_dlerror ());
+    fprintf (stderr,
+             _ ("Initialization of plugin mechanism failed: %s!\n"),
+             lt_dlerror ());
 #endif
-      return;
-    }
+    return;
+  }
 #if WINDOWS
   plibc_init_utf8 ("GNU", PACKAGE, 1);
   plibc_set_stat_size_size (sizeof (((struct stat *) 0)->st_size));
@@ -700,11 +694,13 @@ EXTRACTOR_ltdl_init ()
  * Deinit.
  */
 void __attribute__ ((destructor))
-EXTRACTOR_ltdl_fini () {
+EXTRACTOR_ltdl_fini ()
+{
 #if WINDOWS
   plibc_shutdown ();
 #endif
   lt_dlexit ();
 }
 
+
 /* end of extractor.c */
