@@ -34,32 +34,32 @@ struct EXTRACTOR_SharedMemory
 
   /**
    * W32 handle of the shm into which data is uncompressed
-   */ 
+   */
   HANDLE map;
 
   /**
    * Name of the shm
-   */ 
+   */
   char shm_name[MAX_SHM_NAME + 1];
 
   /**
    * Pointer to the mapped region of the shm (covers the whole shm)
-   */ 
+   */
   void *ptr;
 
   /**
    * Position within shm
-   */ 
+   */
   int64_t pos;
 
   /**
    * Allocated size of the shm
-   */ 
+   */
   int64_t shm_size;
 
   /**
    * Number of bytes in shm (<= shm_size)
-   */ 
+   */
   size_t shm_buf_size;
 
   size_t shm_map_size;
@@ -159,11 +159,12 @@ EXTRACTOR_IPC_shared_memory_create_ (size_t size)
   if (NULL == (shm = malloc (sizeof (struct EXTRACTOR_SharedMemory))))
     return NULL;
 
-  snprintf (shm->shm_name, MAX_SHM_NAME, 
-	    "%slibextractor-shm-%u-%u", 
-	    tpath, getpid(),
-	    (unsigned int) RANDOM());
-  shm->map = CreateFileMapping (INVALID_HANDLE_VALUE, NULL, PAGE_READWRITE, 0, size, shm->shm_name);
+  snprintf (shm->shm_name, MAX_SHM_NAME,
+            "%slibextractor-shm-%u-%u",
+            tpath, getpid (),
+            (unsigned int) RANDOM ());
+  shm->map = CreateFileMapping (INVALID_HANDLE_VALUE, NULL, PAGE_READWRITE, 0,
+                                size, shm->shm_name);
   shm->ptr = MapViewOfFile (shm->map, FILE_MAP_WRITE, 0, 0, size);
   if (shm->ptr == NULL)
   {
@@ -176,6 +177,7 @@ EXTRACTOR_IPC_shared_memory_create_ (size_t size)
   return shm;
 }
 
+
 /**
  * Change the reference counter for this shm instance.
  *
@@ -185,7 +187,7 @@ EXTRACTOR_IPC_shared_memory_create_ (size_t size)
  */
 unsigned int
 EXTRACTOR_IPC_shared_memory_change_rc_ (struct EXTRACTOR_SharedMemory *shm,
-					int delta)
+                                        int delta)
 {
   shm->rc += delta;
   return shm->rc;
@@ -200,7 +202,7 @@ EXTRACTOR_IPC_shared_memory_change_rc_ (struct EXTRACTOR_SharedMemory *shm,
  */
 void
 EXTRACTOR_IPC_shared_memory_destroy_ (struct EXTRACTOR_SharedMemory *shm)
-{  
+{
   if (shm->ptr != NULL)
     UnmapViewOfFile (shm->ptr);
   if (shm->map != 0)
@@ -208,6 +210,7 @@ EXTRACTOR_IPC_shared_memory_destroy_ (struct EXTRACTOR_SharedMemory *shm)
   free (shm);
 }
 
+
 /**
  * Initialize shared memory area from data source.
  *
@@ -219,21 +222,21 @@ EXTRACTOR_IPC_shared_memory_destroy_ (struct EXTRACTOR_SharedMemory *shm)
  */
 ssize_t
 EXTRACTOR_IPC_shared_memory_set_ (struct EXTRACTOR_SharedMemory *shm,
-				  struct EXTRACTOR_Datasource *ds,
-				  uint64_t off,
-				  size_t size)
+                                  struct EXTRACTOR_Datasource *ds,
+                                  uint64_t off,
+                                  size_t size)
 {
   if (-1 ==
       EXTRACTOR_datasource_seek_ (ds, off, SEEK_SET))
-    {
-      LOG ("Failed to set IPC memory due to seek error\n");
-      return -1;
-    }
+  {
+    LOG ("Failed to set IPC memory due to seek error\n");
+    return -1;
+  }
   if (size > shm->shm_size)
     size = shm->shm_size;
   return EXTRACTOR_datasource_read_ (ds,
-				     shm->ptr,
-				     size);
+                                     shm->ptr,
+                                     size);
 }
 
 
@@ -291,7 +294,7 @@ create_selectable_pipe (PHANDLE read_pipe_ptr, PHANDLE write_pipe_ptr,
     static volatile LONG pipe_unique_id;
 
     snprintf (pipename, sizeof pipename, "\\\\.\\pipe\\gnunet-%d-%ld",
-              getpid (), InterlockedIncrement ((LONG *) & pipe_unique_id));
+              getpid (), InterlockedIncrement ((LONG *) &pipe_unique_id));
     /* Use CreateNamedPipe instead of CreatePipe, because the latter
      * returns a write handle that does not permit FILE_READ_ATTRIBUTES
      * access, on versions of win32 earlier than WinXP SP2.
@@ -300,8 +303,8 @@ create_selectable_pipe (PHANDLE read_pipe_ptr, PHANDLE write_pipe_ptr,
      * It's important to only allow a single instance, to ensure that
      * the pipe was not created earlier by some other process, even if
      * the pid has been reused.  We avoid FILE_FLAG_FIRST_PIPE_INSTANCE
-     * because that is only available for Win2k SP2 and WinXP.  */
-    read_pipe = CreateNamedPipeA (pipename, PIPE_ACCESS_INBOUND | dwReadMode, PIPE_TYPE_BYTE | PIPE_READMODE_BYTE, 1,   /* max instances */
+     * because that is only available for Win2k SP2 and WinXP.  */read_pipe = CreateNamedPipeA (pipename, PIPE_ACCESS_INBOUND | dwReadMode,
+                                  PIPE_TYPE_BYTE | PIPE_READMODE_BYTE, 1,                                               /* max instances */
                                   psize,        /* output buffer size */
                                   psize,        /* input buffer size */
                                   NMPWAIT_USE_DEFAULT_WAIT, sa_ptr);
@@ -359,6 +362,7 @@ create_selectable_pipe (PHANDLE read_pipe_ptr, PHANDLE write_pipe_ptr,
   return 0;
 }
 
+
 /**
  * Communicates plugin data (library name, options) to the plugin
  * process. This is only necessary on W32, where this information
@@ -367,10 +371,10 @@ create_selectable_pipe (PHANDLE read_pipe_ptr, PHANDLE write_pipe_ptr,
  * @param plugin plugin context
  *
  * @return 0 on success, -1 on failure
- */ 
+ */
 static int
 write_plugin_data (struct EXTRACTOR_PluginList *plugin,
-    struct EXTRACTOR_Channel *channel)
+                   struct EXTRACTOR_Channel *channel)
 {
   size_t libname_len, shortname_len, opts_len;
   DWORD len;
@@ -418,6 +422,7 @@ write_plugin_data (struct EXTRACTOR_PluginList *plugin,
   return total_len == write_result;
 }
 
+
 /**
  * Create a channel to communicate with a process wrapping
  * the plugin of the given name.  Starts the process as well.
@@ -425,10 +430,10 @@ write_plugin_data (struct EXTRACTOR_PluginList *plugin,
  * @param plugin the plugin
  * @param shm memory to share with the process
  * @return NULL on error, otherwise IPC channel
- */ 
+ */
 struct EXTRACTOR_Channel *
 EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
-			       struct EXTRACTOR_SharedMemory *shm)
+                               struct EXTRACTOR_SharedMemory *shm)
 {
   struct EXTRACTOR_Channel *channel;
   HANDLE p1[2];
@@ -445,18 +450,19 @@ EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
   SECURITY_ATTRIBUTES sa;
 
   if (NULL == (channel = malloc (sizeof (struct EXTRACTOR_Channel))))
-    {
-      LOG_STRERROR ("malloc");
-      return NULL;
-    }
+  {
+    LOG_STRERROR ("malloc");
+    return NULL;
+  }
   memset (channel, 0, sizeof (struct EXTRACTOR_Channel));
   channel->mdata_size = 1024;
   if (NULL == (channel->mdata = malloc (channel->mdata_size)))
-    {
-      LOG_STRERROR ("malloc");
-      free (channel);
-      return NULL;
-    }    channel->shm = shm;
+  {
+    LOG_STRERROR ("malloc");
+    free (channel);
+    return NULL;
+  }
+  channel->shm = shm;
   channel->plugin = plugin;
   channel->size = 0;
 
@@ -464,13 +470,15 @@ EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
   sa.lpSecurityDescriptor = NULL;
   sa.bInheritHandle = FALSE;
 
-  if (0 != create_selectable_pipe (&p1[0], &p1[1], &sa, 1024, FILE_FLAG_OVERLAPPED, FILE_FLAG_OVERLAPPED))
+  if (0 != create_selectable_pipe (&p1[0], &p1[1], &sa, 1024,
+                                   FILE_FLAG_OVERLAPPED, FILE_FLAG_OVERLAPPED))
   {
     LOG_STRERROR ("pipe");
     free (channel);
     return NULL;
   }
-  if (0 != create_selectable_pipe (&p2[0], &p2[1], &sa, 1024, FILE_FLAG_OVERLAPPED, FILE_FLAG_OVERLAPPED))
+  if (0 != create_selectable_pipe (&p2[0], &p2[1], &sa, 1024,
+                                   FILE_FLAG_OVERLAPPED, FILE_FLAG_OVERLAPPED))
   {
     LOG_STRERROR ("pipe");
     CloseHandle (p1[0]);
@@ -479,10 +487,10 @@ EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
     return NULL;
   }
 
-  if (!DuplicateHandle (GetCurrentProcess (), p1[0], GetCurrentProcess (),
-      &p10_os_inh, 0, TRUE, DUPLICATE_SAME_ACCESS)
-      || !DuplicateHandle (GetCurrentProcess (), p2[1], GetCurrentProcess (),
-      &p21_os_inh, 0, TRUE, DUPLICATE_SAME_ACCESS))
+  if (! DuplicateHandle (GetCurrentProcess (), p1[0], GetCurrentProcess (),
+                         &p10_os_inh, 0, TRUE, DUPLICATE_SAME_ACCESS)
+      || ! DuplicateHandle (GetCurrentProcess (), p2[1], GetCurrentProcess (),
+                            &p21_os_inh, 0, TRUE, DUPLICATE_SAME_ACCESS))
   {
     LOG_STRERROR ("DuplicateHandle");
     if (p10_os_inh != INVALID_HANDLE_VALUE)
@@ -506,13 +514,13 @@ EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
    * Also, users might freak out seeing over 9000 rundll32 processes (seeing over 9000 processes named
    * "libextractor_plugin_helper" is probably less confusing).
    */
-  snprintf(cmd, MAX_PATH, 
-	   "rundll32.exe libextractor-3.dll,RundllEntryPoint@16 %lu %lu", 
-	   p10_os_inh, p21_os_inh);
+  snprintf (cmd, MAX_PATH,
+            "rundll32.exe libextractor-3.dll,RundllEntryPoint@16 %lu %lu",
+            p10_os_inh, p21_os_inh);
   cmd[MAX_PATH] = '\0';
   startup.cb = sizeof (STARTUPINFOA);
   if (CreateProcessA (NULL, cmd, NULL, NULL, TRUE, CREATE_SUSPENDED, NULL, NULL,
-      &startup, &proc))
+                      &startup, &proc))
   {
     channel->hProcess = proc.hProcess;
     ResumeThread (proc.hThread);
@@ -544,7 +552,7 @@ EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
   channel->ov_write.hEvent = CreateEvent (NULL, TRUE, TRUE, NULL);
   channel->ov_read.hEvent = CreateEvent (NULL, TRUE, TRUE, NULL);
 
-  if (!write_plugin_data (plugin, channel))
+  if (! write_plugin_data (plugin, channel))
   {
     LOG_STRERROR ("write_plugin_data");
     EXTRACTOR_IPC_channel_destroy_ (channel);
@@ -553,11 +561,11 @@ EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
 
   slen = strlen (shm->shm_name) + 1;
   if (NULL == (init = malloc (sizeof (struct InitMessage) + slen)))
-    {
-      LOG_STRERROR ("malloc");
-      EXTRACTOR_IPC_channel_destroy_ (channel);
-      return NULL;
-    }
+  {
+    LOG_STRERROR ("malloc");
+    EXTRACTOR_IPC_channel_destroy_ (channel);
+    return NULL;
+  }
   init->opcode = MESSAGE_INIT_STATE;
   init->reserved = 0;
   init->reserved2 = 0;
@@ -566,17 +574,18 @@ EXTRACTOR_IPC_channel_create_ (struct EXTRACTOR_PluginList *plugin,
   memcpy (&init[1], shm->shm_name, slen);
   if (sizeof (struct InitMessage) + slen !=
       EXTRACTOR_IPC_channel_send_ (channel, init,
-      sizeof (struct InitMessage) + slen))
-    {
-      LOG ("Failed to send INIT_STATE message to plugin\n");
-      EXTRACTOR_IPC_channel_destroy_ (channel);
-      free (init);
-      return NULL;
-    }
+                                   sizeof (struct InitMessage) + slen))
+  {
+    LOG ("Failed to send INIT_STATE message to plugin\n");
+    EXTRACTOR_IPC_channel_destroy_ (channel);
+    free (init);
+    return NULL;
+  }
   free (init);
   return channel;
 }
 
+
 /**
  * Destroy communication channel with a plugin/process.  Also
  * destroys the process.
@@ -606,6 +615,7 @@ EXTRACTOR_IPC_channel_destroy_ (struct EXTRACTOR_Channel *channel)
   free (channel);
 }
 
+
 /**
  * Send data via the given IPC channel (blocking).
  *
@@ -617,8 +627,8 @@ EXTRACTOR_IPC_channel_destroy_ (struct EXTRACTOR_Channel *channel)
  */
 ssize_t
 EXTRACTOR_IPC_channel_send_ (struct EXTRACTOR_Channel *channel,
-			     const void *data,
-			     size_t size)
+                             const void *data,
+                             size_t size)
 {
   DWORD written;
   DWORD err;
@@ -644,7 +654,8 @@ EXTRACTOR_IPC_channel_send_ (struct EXTRACTOR_Channel *channel,
   channel->ov_write.Pointer = 0;
   channel->ov_write.Internal = 0;
   channel->ov_write.InternalHigh = 0;
-  bresult = WriteFile (channel->cpipe_in, channel->old_buf, size, &written, &channel->ov_write);
+  bresult = WriteFile (channel->cpipe_in, channel->old_buf, size, &written,
+                       &channel->ov_write);
 
   if (bresult == TRUE)
   {
@@ -682,9 +693,9 @@ EXTRACTOR_IPC_channel_send_ (struct EXTRACTOR_Channel *channel,
  */
 int
 EXTRACTOR_IPC_channel_recv_ (struct EXTRACTOR_Channel **channels,
-			     unsigned int num_channels,
-			     EXTRACTOR_ChannelMessageProcessor proc,
-			     void *proc_cls)
+                             unsigned int num_channels,
+                             EXTRACTOR_ChannelMessageProcessor proc,
+                             void *proc_cls)
 {
   DWORD ms;
   DWORD first_ready;
@@ -707,7 +718,8 @@ EXTRACTOR_IPC_channel_recv_ (struct EXTRACTOR_Channel **channels,
     if (WaitForSingleObject (channels[i]->ov_read.hEvent, 0) == WAIT_OBJECT_0)
     {
       ResetEvent (channels[i]->ov_read.hEvent);
-      bresult = ReadFile (channels[i]->cpipe_out, &i, 0, &bytes_read, &channels[i]->ov_read);
+      bresult = ReadFile (channels[i]->cpipe_out, &i, 0, &bytes_read,
+                          &channels[i]->ov_read);
       if (bresult == TRUE)
       {
         SetEvent (channels[i]->ov_read.hEvent);
@@ -728,7 +740,7 @@ EXTRACTOR_IPC_channel_recv_ (struct EXTRACTOR_Channel **channels,
 
   ms = 500;
   first_ready = WaitForMultipleObjects (c, events, FALSE, ms);
-  if (first_ready == WAIT_TIMEOUT || first_ready == WAIT_FAILED)
+  if ((first_ready == WAIT_TIMEOUT) || (first_ready == WAIT_FAILED))
   {
     /* an error or timeout -> something's wrong or all plugins hung up */
     closed_channel = 0;
@@ -765,37 +777,40 @@ EXTRACTOR_IPC_channel_recv_ (struct EXTRACTOR_Channel **channels,
     {
       int ret;
       if (channels[i]->mdata_size == channels[i]->size)
-	{
-	  /* not enough space, need to grow allocation (if allowed) */
-	  if (MAX_META_DATA == channels[i]->mdata_size)
-	    {
-	      LOG ("Inbound message from channel too large, aborting\n");
-	      EXTRACTOR_IPC_channel_destroy_ (channels[i]);
-	      channels[i] = NULL;
-	    }
-	  channels[i]->mdata_size *= 2;
-	  if (channels[i]->mdata_size > MAX_META_DATA)
-	    channels[i]->mdata_size = MAX_META_DATA;
-	  if (NULL == (ndata = realloc (channels[i]->mdata,
-					channels[i]->mdata_size)))
-	    {
-	      LOG_STRERROR ("realloc");
-	      EXTRACTOR_IPC_channel_destroy_ (channels[i]);
-	      channels[i] = NULL;
-	    }
-	  channels[i]->mdata = ndata;
-	}
+      {
+        /* not enough space, need to grow allocation (if allowed) */
+        if (MAX_META_DATA == channels[i]->mdata_size)
+        {
+          LOG ("Inbound message from channel too large, aborting\n");
+          EXTRACTOR_IPC_channel_destroy_ (channels[i]);
+          channels[i] = NULL;
+        }
+        channels[i]->mdata_size *= 2;
+        if (channels[i]->mdata_size > MAX_META_DATA)
+          channels[i]->mdata_size = MAX_META_DATA;
+        if (NULL == (ndata = realloc (channels[i]->mdata,
+                                      channels[i]->mdata_size)))
+        {
+          LOG_STRERROR ("realloc");
+          EXTRACTOR_IPC_channel_destroy_ (channels[i]);
+          channels[i] = NULL;
+        }
+        channels[i]->mdata = ndata;
+      }
       bresult = ReadFile (channels[i]->cpipe_out,
-          &channels[i]->mdata[channels[i]->size],
-          channels[i]->mdata_size - channels[i]->size, &bytes_read, NULL);
+                          &channels[i]->mdata[channels[i]->size],
+                          channels[i]->mdata_size - channels[i]->size,
+                          &bytes_read, NULL);
       if (bresult)
         ret = EXTRACTOR_IPC_process_reply_ (channels[i]->plugin,
-            channels[i]->mdata, channels[i]->size + bytes_read, proc, proc_cls);
-      if (!bresult || -1 == ret)
+                                            channels[i]->mdata,
+                                            channels[i]->size + bytes_read,
+                                            proc, proc_cls);
+      if (! bresult || (-1 == ret))
       {
         DWORD error = GetLastError ();
         SetErrnoFromWinError (error);
-        if (!bresult)
+        if (! bresult)
           LOG_STRERROR ("ReadFile");
         EXTRACTOR_IPC_channel_destroy_ (channels[i]);
         channels[i] = NULL;
@@ -803,12 +818,10 @@ EXTRACTOR_IPC_channel_recv_ (struct EXTRACTOR_Channel **channels,
       else
       {
         memmove (channels[i]->mdata, &channels[i]->mdata[ret],
-          channels[i]->size + bytes_read - ret);
-        channels[i]->size = channels[i]->size + bytes_read- ret;
+                 channels[i]->size + bytes_read - ret);
+        channels[i]->size = channels[i]->size + bytes_read - ret;
       }
     }
   }
   return 1;
 }
-
-
