@@ -116,128 +116,131 @@ struct ProcessingContext
  */
 static int64_t
 plugin_env_seek (void *cls,
-		 int64_t pos,
-		 int whence)
+                 int64_t pos,
+                 int whence)
 {
   struct ProcessingContext *pc = cls;
-  struct SeekRequestMessage srm;
+  struct SeekRequestMessage srm = {
+    .opcode = MESSAGE_SEEK
+  };
   struct UpdateMessage um;
   uint64_t npos;
   unsigned char reply;
   uint16_t wval;
 
   switch (whence)
+  {
+  case SEEK_CUR:
+    if ( (pos < 0) && (pc->read_position < -pos) )
     {
-    case SEEK_CUR:
-      if ( (pos < 0) && (pc->read_position < - pos) )
-	{
-	  LOG ("Invalid seek operation\n");
-	  return -1;
-	}
-      if ((pos > 0) && ((pc->read_position + pos < pc->read_position) ||
-          (pc->read_position + pos > pc->file_size)))
-	{
-	  LOG ("Invalid seek operation\n");
-	  return -1;
-	}
-      npos = (uint64_t) (pc->read_position + pos);
-      wval = 0;
-      break;
-    case SEEK_END:
-      if (pos > 0)
-	{
-	  LOG ("Invalid seek operation\n");
-	  return -1;
-	}
-      if (UINT64_MAX == pc->file_size)
-	{
-	  wval = 2;
-	  npos = (uint64_t) - pos;
-	  break;
-	}
-      pos = (int64_t) (pc->file_size + pos);
-      /* fall-through! */
-    case SEEK_SET:
-      if ( (pos < 0) || (pc->file_size < pos) )
-	{
-	  LOG ("Invalid seek operation\n");
-	  return -1;
-	}
-      npos = (uint64_t) pos;
-      wval = 0;
-      break;
-    default:
       LOG ("Invalid seek operation\n");
       return -1;
     }
+    if ((pos > 0) && ((pc->read_position + pos < pc->read_position) ||
+                      (pc->read_position + pos > pc->file_size)))
+    {
+      LOG ("Invalid seek operation\n");
+      return -1;
+    }
+    npos = (uint64_t) (pc->read_position + pos);
+    wval = 0;
+    break;
+  case SEEK_END:
+    if (pos > 0)
+    {
+      LOG ("Invalid seek operation\n");
+      return -1;
+    }
+    if (UINT64_MAX == pc->file_size)
+    {
+      wval = 2;
+      npos = (uint64_t) -pos;
+      break;
+    }
+    pos = (int64_t) (pc->file_size + pos);
+  /* fall-through! */
+  case SEEK_SET:
+    if ( (pos < 0) || (pc->file_size < pos) )
+    {
+      LOG ("Invalid seek operation\n");
+      return -1;
+    }
+    npos = (uint64_t) pos;
+    wval = 0;
+    break;
+  default:
+    LOG ("Invalid seek operation\n");
+    return -1;
+  }
   if ( (pc->shm_off <= npos) &&
        (pc->shm_off + pc->shm_ready_bytes > npos) &&
        (0 == wval) )
-    {
-      pc->read_position = npos;
-      return (int64_t) npos;
-    }
+  {
+    pc->read_position = npos;
+    return (int64_t) npos;
+  }
   /* need to seek */
   srm.opcode = MESSAGE_SEEK;
   srm.reserved = 0;
   srm.whence = wval;
   srm.requested_bytes = pc->shm_map_size;
   if (0 == wval)
-    {
-      if (srm.requested_bytes > pc->file_size - npos)
-	srm.requested_bytes = pc->file_size - npos;
-    }
+  {
+    if (srm.requested_bytes > pc->file_size - npos)
+      srm.requested_bytes = pc->file_size - npos;
+  }
   else
-    {
-      srm.requested_bytes = npos;
-    }
+  {
+    srm.requested_bytes = npos;
+  }
   srm.file_offset = npos;
   if (-1 == EXTRACTOR_write_all_ (pc->out, &srm, sizeof (srm)))
-    {
-      LOG ("Failed to send MESSAGE_SEEK\n");
-      return -1;
-    }
+  {
+    LOG ("Failed to send MESSAGE_SEEK\n");
+    return -1;
+  }
   if (-1 ==
       EXTRACTOR_read_all_ (pc->in,
-			   &reply, sizeof (reply)))
-    {
-      LOG ("Plugin `%s' failed to read response to MESSAGE_SEEK\n",
-	   pc->plugin->short_libname);
-      return -1;
-    }
+                           &reply, sizeof (reply)))
+  {
+    LOG ("Plugin `%s' failed to read response to MESSAGE_SEEK\n",
+         pc->plugin->short_libname);
+    return -1;
+  }
   if (MESSAGE_UPDATED_SHM != reply)
-    {
-      LOG ("Unexpected reply %d to seek\n", reply);
-      return -1; /* was likely a MESSAGE_DISCARD_STATE */
-    }
+  {
+    LOG ("Unexpected reply %d to seek\n", reply);
+    return -1;   /* was likely a MESSAGE_DISCARD_STATE */
+  }
   if (-1 == EXTRACTOR_read_all_ (pc->in, &um.reserved, sizeof (um) - 1))
-    {
-      LOG ("Failed to read MESSAGE_UPDATED_SHM\n");
-      return -1;
-    }
+  {
+    LOG ("Failed to read MESSAGE_UPDATED_SHM\n");
+    return -1;
+  }
   pc->shm_off = um.shm_off;
   pc->shm_ready_bytes = um.shm_ready_bytes;
   pc->file_size = um.file_size;
   if (2 == wval)
-    {
-      /* convert offset to be absolute from beginning of the file */
-      npos = pc->file_size - npos;
-    }
-   if ( (pc->shm_off <= npos) &&
+  {
+    /* convert offset to be absolute from beginning of the file */
+    npos = pc->file_size - npos;
+  }
+  if ( (pc->shm_off <= npos) &&
        ((pc->shm_off + pc->shm_ready_bytes > npos) ||
-       (pc->file_size == pc->shm_off)) )
-    {
-      pc->read_position = npos;
-      return (int64_t) npos;
-    }
+        (pc->file_size == pc->shm_off)) )
+  {
+    pc->read_position = npos;
+    return (int64_t) npos;
+  }
   /* oops, serious missunderstanding, we asked to seek
      and then were notified about a different position!? */
-  LOG ("Plugin `%s' got invalid MESSAGE_UPDATED_SHM in response to my %d-seek (%llu not in %llu-%llu)\n",
-       pc->plugin->short_libname,
-       (int) wval,
-       (unsigned long long) npos,
-       (unsigned long long) pc->shm_off,
-       (unsigned long long) pc->shm_off + pc->shm_ready_bytes);
+  LOG (
+    "Plugin `%s' got invalid MESSAGE_UPDATED_SHM in response to my %d-seek (%llu not in %llu-%llu)\n",
+    pc->plugin->short_libname,
+    (int) wval,
+    (unsigned long long) npos,
+    (unsigned long long) pc->shm_off,
+    (unsigned long long) pc->shm_off + pc->shm_ready_bytes);
   return -1;
 }
 
@@ -252,7 +255,7 @@ plugin_env_seek (void *cls,
  */
 static ssize_t
 plugin_env_read (void *cls,
-		 void **data,
+                 void **data,
                  size_t count)
 {
   struct ProcessingContext *pc = cls;
@@ -266,10 +269,10 @@ plugin_env_read (void *cls,
            (pc->read_position < pc->file_size)) ||
          (pc->read_position < pc->shm_off) ) &&
        (-1 == plugin_env_seek (pc, pc->read_position, SEEK_SET) ) )
-    {
-      LOG ("Failed to seek to satisfy read\n");
-      return -1;
-    }
+  {
+    LOG ("Failed to seek to satisfy read\n");
+    return -1;
+  }
   if (pc->read_position + count > pc->shm_off + pc->shm_ready_bytes)
     count = pc->shm_off + pc->shm_ready_bytes - pc->read_position;
   dp = pc->shm;
@@ -313,12 +316,12 @@ plugin_env_get_size (void *cls)
  */
 static int
 plugin_env_send_proc (void *cls,
-		      const char *plugin_name,
-		      enum EXTRACTOR_MetaType type,
-		      enum EXTRACTOR_MetaFormat format,
-		      const char *data_mime_type,
-		      const char *data,
-		      size_t data_len)
+                      const char *plugin_name,
+                      enum EXTRACTOR_MetaType type,
+                      enum EXTRACTOR_MetaFormat format,
+                      const char *data_mime_type,
+                      const char *data,
+                      size_t data_len)
 {
   struct ProcessingContext *pc = cls;
   struct MetaMessage mm;
@@ -340,32 +343,32 @@ plugin_env_send_proc (void *cls,
   mm.mime_length = (uint16_t) mime_len;
   mm.value_size = (uint32_t) data_len;
   if ( (sizeof (mm) !=
-	EXTRACTOR_write_all_ (pc->out,
-			      &mm, sizeof (mm))) ||
+        EXTRACTOR_write_all_ (pc->out,
+                              &mm, sizeof (mm))) ||
        (mime_len !=
-	EXTRACTOR_write_all_ (pc->out,
-			      data_mime_type, mime_len)) ||
+        EXTRACTOR_write_all_ (pc->out,
+                              data_mime_type, mime_len)) ||
        (data_len !=
-	EXTRACTOR_write_all_ (pc->out,
-			      data, data_len)) )
-    {
-      LOG ("Failed to send meta message\n");
-      return 1;
-    }
+        EXTRACTOR_write_all_ (pc->out,
+                              data, data_len)) )
+  {
+    LOG ("Failed to send meta message\n");
+    return 1;
+  }
   if (-1 ==
       EXTRACTOR_read_all_ (pc->in,
-			   &reply, sizeof (reply)))
-    {
-      LOG ("Failed to read response to meta message\n");
-      return 1;
-    }
+                           &reply, sizeof (reply)))
+  {
+    LOG ("Failed to read response to meta message\n");
+    return 1;
+  }
   if (MESSAGE_DISCARD_STATE == reply)
     return 1;
   if (MESSAGE_CONTINUE_EXTRACTING != reply)
-    {
-      LOG ("Received unexpected reply to meta data: %d\n", reply);
-      return 1;
-    }
+  {
+    LOG ("Received unexpected reply to meta data: %d\n", reply);
+    return 1;
+  }
   return 0;
 }
 
@@ -379,37 +382,39 @@ plugin_env_send_proc (void *cls,
 static int
 handle_init_message (struct ProcessingContext *pc)
 {
-  struct InitMessage init;
+  struct InitMessage init = {
+    .opcode = MESSAGE_INIT_STATE
+  };
 
   if (NULL != pc->shm)
-    {
-      LOG ("Cannot handle 'init' message, have already been initialized\n");
-      return -1;
-    }
+  {
+    LOG ("Cannot handle 'init' message, have already been initialized\n");
+    return -1;
+  }
   if (sizeof (struct InitMessage) - 1
       != EXTRACTOR_read_all_ (pc->in,
-		   &init.reserved,
-		   sizeof (struct InitMessage) - 1))
-    {
-      LOG ("Failed to read 'init' message\n");
-      return -1;
-    }
+                              &init.reserved,
+                              sizeof (struct InitMessage) - 1))
+  {
+    LOG ("Failed to read 'init' message\n");
+    return -1;
+  }
   if (init.shm_name_length > MAX_SHM_NAME)
-    {
-      LOG ("Invalid 'init' message\n");
-      return -1;
-    }
+  {
+    LOG ("Invalid 'init' message\n");
+    return -1;
+  }
   {
     char shm_name[init.shm_name_length + 1];
 
     if (init.shm_name_length
-	!= EXTRACTOR_read_all_ (pc->in,
-		     shm_name,
-		     init.shm_name_length))
-      {
-	LOG ("Failed to read 'init' message\n");
-	return -1;
-      }
+        != EXTRACTOR_read_all_ (pc->in,
+                                shm_name,
+                                init.shm_name_length))
+    {
+      LOG ("Failed to read 'init' message\n");
+      return -1;
+    }
     shm_name[init.shm_name_length] = '\0';
 
     pc->shm_map_size = init.shm_map_size;
@@ -427,20 +432,20 @@ handle_init_message (struct ProcessingContext *pc)
 #else
     pc->shm_id = shm_open (shm_name, O_RDONLY, 0);
     if (-1 == pc->shm_id)
-      {
-	LOG_STRERROR_FILE ("open", shm_name);
-	return -1;
-      }
+    {
+      LOG_STRERROR_FILE ("open", shm_name);
+      return -1;
+    }
     pc->shm = mmap (NULL,
-		    pc->shm_map_size,
-		    PROT_READ,
-		    MAP_SHARED,
-		    pc->shm_id, 0);
+                    pc->shm_map_size,
+                    PROT_READ,
+                    MAP_SHARED,
+                    pc->shm_id, 0);
     if ( ((void*) -1) == pc->shm)
-      {
-	LOG_STRERROR_FILE ("mmap", shm_name);
-	return -1;
-      }
+    {
+      LOG_STRERROR_FILE ("mmap", shm_name);
+      return -1;
+    }
 #endif
   }
   return 0;
@@ -456,18 +461,20 @@ handle_init_message (struct ProcessingContext *pc)
 static int
 handle_start_message (struct ProcessingContext *pc)
 {
-  struct StartMessage start;
+  struct StartMessage start = {
+    .opcode = MESSAGE_EXTRACT_START
+  };
   struct EXTRACTOR_ExtractContext ec;
   char done;
 
   if (sizeof (struct StartMessage) - 1
       != EXTRACTOR_read_all_ (pc->in,
-		   &start.reserved,
-		   sizeof (struct StartMessage) - 1))
-    {
-      LOG ("Failed to read 'start' message\n");
-      return -1;
-    }
+                              &start.reserved,
+                              sizeof (struct StartMessage) - 1))
+  {
+    LOG ("Failed to read 'start' message\n");
+    return -1;
+  }
   pc->shm_ready_bytes = start.shm_ready_bytes;
   pc->file_size = start.file_size;
   pc->read_position = 0;
@@ -481,22 +488,22 @@ handle_start_message (struct ProcessingContext *pc)
   pc->plugin->extract_method (&ec);
   done = MESSAGE_DONE;
   if (-1 == EXTRACTOR_write_all_ (pc->out, &done, sizeof (done)))
-    {
-      LOG ("Failed to write 'done' message\n");
-      return -1;
-    }
+  {
+    LOG ("Failed to write 'done' message\n");
+    return -1;
+  }
   if ( (NULL != pc->plugin->specials) &&
        (NULL != strstr (pc->plugin->specials, "force-kill")) )
-    {
-      /* we're required to die after each file since this
-	 plugin only supports a single file at a time */
-#if !WINDOWS
-      fsync (pc->out);
+  {
+    /* we're required to die after each file since this
+ plugin only supports a single file at a time */
+#if ! WINDOWS
+    fsync (pc->out);
 #else
-      _commit (pc->out);
+    _commit (pc->out);
 #endif
-      _exit (0);
-    }
+    _exit (0);
+  }
   return 0;
 }
 
@@ -511,43 +518,43 @@ static void
 process_requests (struct ProcessingContext *pc)
 {
   while (1)
-    {
-      unsigned char code;
+  {
+    unsigned char code;
 
-      if (1 != EXTRACTOR_read_all_ (pc->in, &code, 1))
-	{
-	  LOG ("Failed to read next request\n");
-	  break;
-	}
-      switch (code)
-	{
-	case MESSAGE_INIT_STATE:
-	  if (0 != handle_init_message (pc))
-	    {
-	      LOG ("Failure to handle INIT\n");
-	      return;
-	    }
-	  break;
-	case MESSAGE_EXTRACT_START:
-	  if (0 != handle_start_message (pc))
-	    {
-	      LOG ("Failure to handle START\n");
-	      return;
-	    }
-	  break;
-	case MESSAGE_UPDATED_SHM:
-	  LOG ("Illegal message\n");
-	  /* not allowed here, we're not waiting for SHM to move! */
-	  return;
-	case MESSAGE_DISCARD_STATE:
-	  /* odd, we're already in the start state... */
-	  continue;
-	default:
-	  LOG ("Received invalid messag %d\n", (int) code);
-	  /* error, unexpected message */
-	  return;
-	}
+    if (1 != EXTRACTOR_read_all_ (pc->in, &code, 1))
+    {
+      LOG ("Failed to read next request\n");
+      break;
     }
+    switch (code)
+    {
+    case MESSAGE_INIT_STATE:
+      if (0 != handle_init_message (pc))
+      {
+        LOG ("Failure to handle INIT\n");
+        return;
+      }
+      break;
+    case MESSAGE_EXTRACT_START:
+      if (0 != handle_start_message (pc))
+      {
+        LOG ("Failure to handle START\n");
+        return;
+      }
+      break;
+    case MESSAGE_UPDATED_SHM:
+      LOG ("Illegal message\n");
+      /* not allowed here, we're not waiting for SHM to move! */
+      return;
+    case MESSAGE_DISCARD_STATE:
+      /* odd, we're already in the start state... */
+      continue;
+    default:
+      LOG ("Received invalid messag %d\n", (int) code);
+      /* error, unexpected message */
+      return;
+    }
+  }
 }
 
 
@@ -560,7 +567,7 @@ process_requests (struct ProcessingContext *pc)
  */
 static void
 open_dev_null (int target_fd,
-	       int flags)
+               int flags)
 {
   int fd;
 
@@ -570,10 +577,10 @@ open_dev_null (int target_fd,
   fd = open ("\\\\?\\NUL", flags);
 #endif
   if (-1 == fd)
-    {
-      LOG_STRERROR_FILE ("open", "/dev/null");
-      return; /* good luck */
-    }
+  {
+    LOG_STRERROR_FILE ("open", "/dev/null");
+    return;   /* good luck */
+  }
   if (fd == target_fd)
     return; /* already done */
   if (-1 == dup2 (fd, target_fd))
@@ -598,32 +605,32 @@ open_dev_null (int target_fd,
  */
 void
 EXTRACTOR_plugin_main_ (struct EXTRACTOR_PluginList *plugin,
-			int in, int out)
+                        int in, int out)
 {
   struct ProcessingContext pc;
 
   if (0 != EXTRACTOR_plugin_load_ (plugin))
-    {
+  {
 #if DEBUG
-      fprintf (stderr, "Plugin `%s' failed to load!\n",
-	       plugin->short_libname);
+    fprintf (stderr, "Plugin `%s' failed to load!\n",
+             plugin->short_libname);
 #endif
-      return;
-    }
+    return;
+  }
   if ( (NULL != plugin->specials) &&
        (NULL != strstr (plugin->specials, "close-stderr")))
-    {
-      if (0 != close (2))
-	LOG_STRERROR ("close");
-      open_dev_null (2, O_WRONLY);
-    }
+  {
+    if (0 != close (2))
+      LOG_STRERROR ("close");
+    open_dev_null (2, O_WRONLY);
+  }
   if ( (NULL != plugin->specials) &&
        (NULL != strstr (plugin->specials, "close-stdout")))
-    {
-      if (0 != close (1))
-	LOG_STRERROR ("close");
-      open_dev_null (1, O_WRONLY);
-    }
+  {
+    if (0 != close (1))
+      LOG_STRERROR ("close");
+    open_dev_null (1, O_WRONLY);
+  }
   pc.plugin = plugin;
   pc.in = in;
   pc.out = out;
@@ -643,10 +650,10 @@ EXTRACTOR_plugin_main_ (struct EXTRACTOR_PluginList *plugin,
        (((void*) 1) != pc.shm) )
     munmap (pc.shm, pc.shm_map_size);
   if (-1 != pc.shm_id)
-    {
-      if (0 != close (pc.shm_id))
-	LOG_STRERROR ("close");
-    }
+  {
+    if (0 != close (pc.shm_id))
+      LOG_STRERROR ("close");
+  }
 #endif
 }
 
@@ -668,43 +675,43 @@ read_plugin_data (int fd)
 
   // FIXME: check for errors from 'EXTRACTOR_read_all_'!
   if (NULL == (ret = malloc (sizeof (struct EXTRACTOR_PluginList))))
-    {
-      LOG_STRERROR ("malloc");
-      return NULL;
-    }
+  {
+    LOG_STRERROR ("malloc");
+    return NULL;
+  }
   memset (ret, 0, sizeof (struct EXTRACTOR_PluginList));
   /*GetSystemInfo (&si);
   ret->allocation_granularity = si.dwAllocationGranularity;*/
   EXTRACTOR_read_all_ (fd, &i, sizeof (size_t));
   if (NULL == (ret->libname = malloc (i)))
-    {
-      free (ret);
-      return NULL;
-    }
+  {
+    free (ret);
+    return NULL;
+  }
   EXTRACTOR_read_all_ (fd, ret->libname, i);
   ret->libname[i - 1] = '\0';
   EXTRACTOR_read_all_ (fd, &i, sizeof (size_t));
   if (NULL == (ret->short_libname = malloc (i)))
-    {
-      free (ret->libname);
-      free (ret);
-      return NULL;
-    }
+  {
+    free (ret->libname);
+    free (ret);
+    return NULL;
+  }
   EXTRACTOR_read_all_ (fd, ret->short_libname, i);
   ret->short_libname[i - 1] = '\0';
   EXTRACTOR_read_all_ (fd, &i, sizeof (size_t));
   if (0 == i)
-    {
-      ret->plugin_options = NULL;
-      return ret;
-    }
+  {
+    ret->plugin_options = NULL;
+    return ret;
+  }
   if (NULL == (ret->plugin_options = malloc (i)))
-    {
-      free (ret->short_libname);
-      free (ret->libname);
-      free (ret);
-      return NULL;
-    }
+  {
+    free (ret->short_libname);
+    free (ret->libname);
+    free (ret);
+    return NULL;
+  }
   EXTRACTOR_read_all_ (fd, ret->plugin_options, i);
   ret->plugin_options[i - 1] = '\0';
   return ret;
@@ -716,9 +723,9 @@ read_plugin_data (int fd)
  */
 void CALLBACK
 RundllEntryPoint (HWND hwnd,
-		  HINSTANCE hinst,
-		  LPSTR lpszCmdLine,
-		  int nCmdShow)
+                  HINSTANCE hinst,
+                  LPSTR lpszCmdLine,
+                  int nCmdShow)
 {
   struct EXTRACTOR_PluginList *plugin;
   intptr_t in_h;
@@ -732,11 +739,11 @@ RundllEntryPoint (HWND hwnd,
   setmode (in, _O_BINARY);
   setmode (out, _O_BINARY);
   if (NULL == (plugin = read_plugin_data (in)))
-    {
-      close (in);
-      close (out);
-      return;
-    }
+  {
+    close (in);
+    close (out);
+    return;
+  }
   EXTRACTOR_plugin_main_ (plugin, in, out);
   close (in);
   close (out);
@@ -745,8 +752,7 @@ RundllEntryPoint (HWND hwnd,
    * called by the OS) or call FreeLibrary() on it directly or
    * indirectly.
    * By terminating here we alleviate that problem.
-   */
-  TerminateProcess (GetCurrentProcess (), 0);
+   */TerminateProcess (GetCurrentProcess (), 0);
 }
 
 
@@ -755,9 +761,9 @@ RundllEntryPoint (HWND hwnd,
  */
 void CALLBACK
 RundllEntryPointA (HWND hwnd,
-		   HINSTANCE hinst,
-		   LPSTR lpszCmdLine,
-		   int nCmdShow)
+                   HINSTANCE hinst,
+                   LPSTR lpszCmdLine,
+                   int nCmdShow)
 {
   return RundllEntryPoint (hwnd, hinst, lpszCmdLine, nCmdShow);
 }
