@@ -39,9 +39,9 @@
  */
 static void *
 get_symbol_with_prefix (void *lib_handle,
-			const char *template,
-			const char *prefix,
-			const char **options)
+                        const char *template,
+                        const char *prefix,
+                        const char **options)
 {
   char *name;
   void *symbol;
@@ -56,55 +56,55 @@ get_symbol_with_prefix (void *lib_handle,
     return NULL;
   sym_name++;
   if (NULL == (sym = strdup (sym_name)))
-    {
-      LOG_STRERROR ("strdup");
-      return NULL;
-    }
+  {
+    LOG_STRERROR ("strdup");
+    return NULL;
+  }
   if (NULL != (dot = strchr (sym, '.')))
     *dot = '\0';
-  if (NULL == (name = malloc(strlen(sym) + strlen(template) + 1)))
-    {
-      free (sym);
-      return NULL;
-    }
-  sprintf(name,
-	  template,
-	  sym);
+  if (NULL == (name = malloc (strlen (sym) + strlen (template) + 1)))
+  {
+    free (sym);
+    return NULL;
+  }
+  sprintf (name,
+           template,
+           sym);
   /* try without '_' first */
   symbol = lt_dlsym (lib_handle, name + 1);
   if (NULL == symbol)
+  {
+    /* now try with the '_' */
+    char *first_error = strdup (lt_dlerror ());
+    symbol = lt_dlsym (lib_handle, name);
+    if (NULL == symbol)
     {
-      /* now try with the '_' */
-      char *first_error = strdup (lt_dlerror ());
-      symbol = lt_dlsym (lib_handle, name);
-      if (NULL == symbol)
-	{
-	  LOG ("Resolving symbol `%s' failed, "
-	       "so I tried `%s', but that failed also.  Errors are: "
-	       "`%s' and `%s'.\n",
-	       name+1,
-	       name,
-	       first_error == NULL ? "out of memory" : first_error,
-	       lt_dlerror ());
-	}
-      if (NULL != first_error)
-	free (first_error);
+      LOG ("Resolving symbol `%s' failed, "
+           "so I tried `%s', but that failed also.  Errors are: "
+           "`%s' and `%s'.\n",
+           name + 1,
+           name,
+           first_error == NULL ? "out of memory" : first_error,
+           lt_dlerror ());
     }
+    if (NULL != first_error)
+      free (first_error);
+  }
 
   if ( (NULL != symbol) &&
        (NULL != options) )
-    {
-      /* get special options */
-      sprintf (name,
-	       "_EXTRACTOR_%s_options",
-	       sym);
-      /* try without '_' first */
-      opt_fun = lt_dlsym (lib_handle, name + 1);
-      if (NULL == opt_fun)
-	opt_fun = lt_dlsym (lib_handle, name);
-      if (NULL != opt_fun)
-	*options = opt_fun ();
-    }
+  {
+    /* get special options */
+    sprintf (name,
+             "_EXTRACTOR_%s_options",
+             sym);
+    /* try without '_' first */
+    opt_fun = lt_dlsym (lib_handle, name + 1);
+    if (NULL == opt_fun)
+      opt_fun = lt_dlsym (lib_handle, name);
+    if (NULL != opt_fun)
+      *options = opt_fun ();
+  }
   free (sym);
   free (name);
   return symbol;
@@ -131,12 +131,12 @@ EXTRACTOR_plugin_load_ (struct EXTRACTOR_PluginList *plugin)
   if (NULL == plugin->libname)
     plugin->libname = EXTRACTOR_find_plugin_ (plugin->short_libname);
   if (NULL == plugin->libname)
-    {
-      LOG ("Failed to find plugin `%s'\n",
-	   plugin->short_libname);
-      plugin->flags = EXTRACTOR_OPTION_DISABLED;
-      return -1;
-    }
+  {
+    LOG ("Failed to find plugin `%s'\n",
+         plugin->short_libname);
+    plugin->flags = EXTRACTOR_OPTION_DISABLED;
+    return -1;
+  }
   lt_dladvise_init (&advise);
   lt_dladvise_ext (&advise);
   lt_dladvise_local (&advise);
@@ -144,51 +144,51 @@ EXTRACTOR_plugin_load_ (struct EXTRACTOR_PluginList *plugin)
   wlibname[0] = L'\0';
   llibname[0] = '\0';
   if ( (MultiByteToWideChar (CP_UTF8, 0, plugin->libname, -1,
-			     wlibname, sizeof (wlibname)) <= 0) ||
+                             wlibname, sizeof (wlibname)) <= 0) ||
        (WideCharToMultiByte (CP_ACP, 0, wlibname, -1,
-			     llibname, sizeof (llibname), NULL, NULL) < 0) )
-    {
-      LOG ("Loading `%s' plugin failed: %s\n",
-	   plugin->short_libname,
-	   "can't convert plugin name to local encoding");
-      free (plugin->libname);
-      plugin->libname = NULL;
-      plugin->flags = EXTRACTOR_OPTION_DISABLED;
-      return -1;
+                             llibname, sizeof (llibname), NULL, NULL) < 0) )
+  {
+    LOG ("Loading `%s' plugin failed: %s\n",
+         plugin->short_libname,
+         "can't convert plugin name to local encoding");
+    free (plugin->libname);
+    plugin->libname = NULL;
+    plugin->flags = EXTRACTOR_OPTION_DISABLED;
+    return -1;
   }
   plugin->libraryHandle = lt_dlopenadvise (llibname,
-					   advise);
+                                           advise);
 #else
   plugin->libraryHandle = lt_dlopenadvise (plugin->libname,
-					   advise);
+                                           advise);
 #endif
   lt_dladvise_destroy (&advise);
   if (NULL == plugin->libraryHandle)
-    {
-      LOG ("Loading `%s' plugin failed (using name `%s'): %s\n",
-	   plugin->short_libname,
-	   plugin->libname,
-	   lt_dlerror ());
-      free (plugin->libname);
-      plugin->libname = NULL;
-      plugin->flags = EXTRACTOR_OPTION_DISABLED;
-      return -1;
-    }
+  {
+    LOG ("Loading `%s' plugin failed (using name `%s'): %s\n",
+         plugin->short_libname,
+         plugin->libname,
+         lt_dlerror ());
+    free (plugin->libname);
+    plugin->libname = NULL;
+    plugin->flags = EXTRACTOR_OPTION_DISABLED;
+    return -1;
+  }
   plugin->extract_method = get_symbol_with_prefix (plugin->libraryHandle,
-						   "_EXTRACTOR_%s_extract_method",
-						   plugin->libname,
-						   &plugin->specials);
+                                                   "_EXTRACTOR_%s_extract_method",
+                                                   plugin->libname,
+                                                   &plugin->specials);
   if (NULL == plugin->extract_method)
-    {
-      LOG ("Resolving `extract' method of plugin `%s' failed: %s\n",
-	   plugin->short_libname,
-	   lt_dlerror ());
-      lt_dlclose (plugin->libraryHandle);
-      free (plugin->libname);
-      plugin->libname = NULL;
-      plugin->flags = EXTRACTOR_OPTION_DISABLED;
-      return -1;
-    }
+  {
+    LOG ("Resolving `extract' method of plugin `%s' failed: %s\n",
+         plugin->short_libname,
+         lt_dlerror ());
+    lt_dlclose (plugin->libraryHandle);
+    free (plugin->libname);
+    plugin->libname = NULL;
+    plugin->flags = EXTRACTOR_OPTION_DISABLED;
+    return -1;
+  }
   return 0;
 }
 
@@ -204,9 +204,9 @@ EXTRACTOR_plugin_load_ (struct EXTRACTOR_PluginList *plugin)
  */
 struct EXTRACTOR_PluginList *
 EXTRACTOR_plugin_add (struct EXTRACTOR_PluginList *prev,
-		      const char *library,
-		      const char *options,
-		      enum EXTRACTOR_Options flags)
+                      const char *library,
+                      const char *options,
+                      enum EXTRACTOR_Options flags)
 {
   struct EXTRACTOR_PluginList *plugin;
   struct EXTRACTOR_PluginList *pos;
@@ -214,22 +214,23 @@ EXTRACTOR_plugin_add (struct EXTRACTOR_PluginList *prev,
 
   for (pos = prev; NULL != pos; pos = pos->next)
     if (0 == strcmp (pos->short_libname, library))
-      return prev; /* no change, library already loaded */
-  if (NULL == (libname = EXTRACTOR_find_plugin_ (library)))
-    {
-      LOG ("Could not load plugin `%s'\n",
-	   library);
       return prev;
-    }
+  /* no change, library already loaded */
+  if (NULL == (libname = EXTRACTOR_find_plugin_ (library)))
+  {
+    LOG ("Could not load plugin `%s'\n",
+         library);
+    return prev;
+  }
   if (NULL == (plugin = malloc (sizeof (struct EXTRACTOR_PluginList))))
     return prev;
   memset (plugin, 0, sizeof (struct EXTRACTOR_PluginList));
   plugin->next = prev;
   if (NULL == (plugin->short_libname = strdup (library)))
-    {
-      free (plugin);
-      return NULL;
-    }
+  {
+    free (plugin);
+    return NULL;
+  }
   plugin->libname = libname;
   plugin->flags = flags;
   if (NULL != options)
@@ -258,8 +259,8 @@ EXTRACTOR_plugin_add (struct EXTRACTOR_PluginList *prev,
  */
 struct EXTRACTOR_PluginList *
 EXTRACTOR_plugin_add_config (struct EXTRACTOR_PluginList *prev,
-			     const char *config,
-			     enum EXTRACTOR_Options flags)
+                             const char *config,
+                             enum EXTRACTOR_Options flags)
 {
   char *cpy;
   size_t pos;
@@ -276,55 +277,55 @@ EXTRACTOR_plugin_add_config (struct EXTRACTOR_PluginList *prev,
   last = 0;
   lastconf = 0;
   while (pos < len)
+  {
+    while ( (':' != cpy[pos]) &&
+            ('\0' != cpy[pos]) &&
+            ('(' != cpy[pos]) )
+      pos++;
+    switch (cpy[pos])
     {
-      while ( (':' != cpy[pos]) &&
-	      ('\0' != cpy[pos]) &&
-	      ('(' != cpy[pos]) )
-	pos++;
-      switch (cpy[pos])
-	{
-	case '(':
-	  cpy[pos++] = '\0';	/* replace '(' by termination */
-	  lastconf = pos;         /* start config from here, after (. */
-	  while ( ('\0' != cpy[pos]) &&
-		  (')' != cpy[pos]))
-	    pos++; /* config until ) or EOS. */
-	  if (')' == cpy[pos])
-	    {
-	      cpy[pos++] = '\0'; /* write end of config here. */
-	      while ( (':' != cpy[pos]) &&
-		      ('\0' != cpy[pos]) )
-		pos++; /* forward until real end of string found. */
-	      cpy[pos++] = '\0';
-	    }
-	  else
-	    {
-	      cpy[pos++] = '\0'; /* end of string. */
-	    }
-	  break;
-	case ':':
-	case '\0':
-	  lastconf = -1;         /* NULL config when no (). */
-	  cpy[pos++] = '\0';	/* replace ':' by termination */
-	  break;
-	default:
-	  ABORT ();
-	}
-      if ('-' == cpy[last])
-	{
-	  last++;
-	  prev = EXTRACTOR_plugin_remove (prev,
-					  &cpy[last]);
-	}
+    case '(':
+      cpy[pos++] = '\0'; /* replace '(' by termination */
+      lastconf = pos;       /* start config from here, after (. */
+      while ( ('\0' != cpy[pos]) &&
+              (')' != cpy[pos]))
+        pos++; /* config until ) or EOS. */
+      if (')' == cpy[pos])
+      {
+        cpy[pos++] = '\0'; /* write end of config here. */
+        while ( (':' != cpy[pos]) &&
+                ('\0' != cpy[pos]) )
+          pos++; /* forward until real end of string found. */
+        cpy[pos++] = '\0';
+      }
       else
-	{
-	  prev = EXTRACTOR_plugin_add (prev,
-				       &cpy[last],
-				       (-1 != lastconf) ? &cpy[lastconf] : NULL,
-				       flags);
-	}
-      last = pos;
+      {
+        cpy[pos++] = '\0'; /* end of string. */
+      }
+      break;
+    case ':':
+    case '\0':
+      lastconf = -1;       /* NULL config when no (). */
+      cpy[pos++] = '\0'; /* replace ':' by termination */
+      break;
+    default:
+      ABORT ();
     }
+    if ('-' == cpy[last])
+    {
+      last++;
+      prev = EXTRACTOR_plugin_remove (prev,
+                                      &cpy[last]);
+    }
+    else
+    {
+      prev = EXTRACTOR_plugin_add (prev,
+                                   &cpy[last],
+                                   (-1 != lastconf) ? &cpy[lastconf] : NULL,
+                                   flags);
+    }
+    last = pos;
+  }
   free (cpy);
   return prev;
 }
@@ -339,7 +340,7 @@ EXTRACTOR_plugin_add_config (struct EXTRACTOR_PluginList *prev,
  */
 struct EXTRACTOR_PluginList *
 EXTRACTOR_plugin_remove (struct EXTRACTOR_PluginList *prev,
-			 const char *library)
+                         const char *library)
 {
   struct EXTRACTOR_PluginList *pos;
   struct EXTRACTOR_PluginList *first;
@@ -347,17 +348,17 @@ EXTRACTOR_plugin_remove (struct EXTRACTOR_PluginList *prev,
   pos = prev;
   first = prev;
   while ( (NULL != pos) &&
-	  (0 != strcmp (pos->short_libname, library)) )
-    {
-      prev = pos;
-      pos = pos->next;
-    }
+          (0 != strcmp (pos->short_libname, library)) )
+  {
+    prev = pos;
+    pos = pos->next;
+  }
   if (NULL == pos)
-    {
-      LOG ("Unloading plugin `%s' failed!\n",
-	   library);
-      return first;
-    }
+  {
+    LOG ("Unloading plugin `%s' failed!\n",
+         library);
+    return first;
+  }
   /* found, close library */
   if (first == pos)
     first = pos->next;
@@ -374,7 +375,7 @@ EXTRACTOR_plugin_remove (struct EXTRACTOR_PluginList *prev,
     free (pos->libname);
   free (pos->plugin_options);
   if (NULL != pos->libraryHandle)
-	lt_dlclose (pos->libraryHandle);
+    lt_dlclose (pos->libraryHandle);
   free (pos);
   return first;
 }
