@@ -30,29 +30,32 @@ main (int argc, char *argv[])
 {
   struct EXTRACTOR_PluginList *arg;
 
-  /* change environment to find 'extractor_test' plugin which is 
+  /* change environment to find 'extractor_test' plugin which is
      not installed but should be in the current directory (or .libs)
      on 'make check' */
   if (0 != putenv ("LIBEXTRACTOR_PREFIX=." PATH_SEPARATOR_STR ".libs/"))
-    fprintf (stderr, 
-	     "Failed to update my environment, plugin loading may fail: %s\n",
-	     strerror (errno));
+    fprintf (stderr,
+             "Failed to update my environment, plugin loading may fail: %s\n",
+             strerror (errno));
 
   /* do some load/unload tests */
-  arg = EXTRACTOR_plugin_add (NULL, "test", NULL, EXTRACTOR_OPTION_DEFAULT_POLICY);
-  if (arg != EXTRACTOR_plugin_add (arg, "test", NULL, EXTRACTOR_OPTION_DEFAULT_POLICY))
-    {
-      fprintf (stderr,
-	       "Could load plugin twice, that should not be allowed\n");
-    }
+  arg = EXTRACTOR_plugin_add (NULL, "test", NULL,
+                              EXTRACTOR_OPTION_DEFAULT_POLICY);
+  if (arg != EXTRACTOR_plugin_add (arg, "test", NULL,
+                                   EXTRACTOR_OPTION_DEFAULT_POLICY))
+  {
+    fprintf (stderr,
+             "Could load plugin twice, that should not be allowed\n");
+  }
   arg = EXTRACTOR_plugin_remove (arg, "test");
   if (NULL != arg)
-    {
-      fprintf (stderr,
-	       "add-remove test failed!\n");
-      return -1;
-    }
+  {
+    fprintf (stderr,
+             "add-remove test failed!\n");
+    return -1;
+  }
   return 0;
 }
 
+
 /* end of test_plugin_loading.c */
