@@ -37,16 +37,16 @@
  */
 static int
 gif_read_func (GifFileType *ft,
-	       GifByteType *bt,
-	       int arg)
+               GifByteType *bt,
+               int arg)
 {
   struct EXTRACTOR_ExtractContext *ec = ft->UserData;
   void *data;
   ssize_t ret;
 
   ret = ec->read (ec->cls,
-		  &data,
-		  arg);
+                  &data,
+                  arg);
   if (-1 == ret)
     return -1;
   memcpy (bt, data, ret);
@@ -75,7 +75,7 @@ EXTRACTOR_gif_extract_method (struct EXTRACTOR_ExtractContext *ec)
 
   gif_error = 0;
   gif_file = DGifOpen (ec, &gif_read_func, &gif_error);
-  if (gif_file == NULL || gif_error != 0)
+  if ((gif_file == NULL) || (gif_error != 0))
   {
     if (gif_file != NULL)
 #if GIFLIB_MAJOR < 5 || GIFLIB_MINOR < 1
@@ -88,57 +88,58 @@ EXTRACTOR_gif_extract_method (struct EXTRACTOR_ExtractContext *ec)
 #endif
   if (0 !=
       ec->proc (ec->cls,
-		"gif",
-		EXTRACTOR_METATYPE_MIMETYPE,
-		EXTRACTOR_METAFORMAT_UTF8,
-		"text/plain",
-		"image/gif",
-		strlen ("image/gif") + 1))
+                "gif",
+                EXTRACTOR_METATYPE_MIMETYPE,
+                EXTRACTOR_METAFORMAT_UTF8,
+                "text/plain",
+                "image/gif",
+                strlen ("image/gif") + 1))
     return;
   snprintf (dims,
-	    sizeof (dims),
-	    "%dx%d",
-	    gif_file->SHeight,
-	    gif_file->SWidth);
+            sizeof (dims),
+            "%dx%d",
+            gif_file->SHeight,
+            gif_file->SWidth);
   if (0 !=
       ec->proc (ec->cls,
-		"gif",
-		EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
-		EXTRACTOR_METAFORMAT_UTF8,
-		"text/plain",
-		dims,
-		strlen (dims) + 1))
+                "gif",
+                EXTRACTOR_METATYPE_IMAGE_DIMENSIONS,
+                EXTRACTOR_METAFORMAT_UTF8,
+                "text/plain",
+                dims,
+                strlen (dims) + 1))
     return;
   while (1)
+  {
+    if (GIF_OK !=
+        DGifGetRecordType (gif_file,
+                           &gif_type))
+      break;
+    if (UNDEFINED_RECORD_TYPE == gif_type)
+      break;
+    if (EXTENSION_RECORD_TYPE != gif_type)
+      continue;
+    if (GIF_OK !=
+        DGifGetExtension (gif_file, &et, &ext))
+      continue;
+    if (NULL == ext)
+      continue;
+    if (COMMENT_EXT_FUNC_CODE == et)
     {
-      if (GIF_OK !=
-	  DGifGetRecordType (gif_file,
-			     &gif_type))
-	break;
-      if (UNDEFINED_RECORD_TYPE == gif_type)
-	break;
-      if (EXTENSION_RECORD_TYPE != gif_type)
-	continue;
-      if (GIF_OK !=
-	  DGifGetExtension (gif_file, &et, &ext))
-	continue;
-      if (NULL == ext)
-        continue;
-      if (COMMENT_EXT_FUNC_CODE == et)
-	{
-	  ec->proc (ec->cls,
-		    "gif",
-		    EXTRACTOR_METATYPE_COMMENT,
-		    EXTRACTOR_METAFORMAT_C_STRING,
-		    "text/plain",
-		    (char*) &ext[1],
-		    (uint8_t) ext[0]);
-	  break;
-	}
-      while ( (GIF_ERROR !=
-	       DGifGetExtensionNext(gif_file, &ext)) &&
-	      (NULL != ext) ) ; /* keep going */
+      ec->proc (ec->cls,
+                "gif",
+                EXTRACTOR_METATYPE_COMMENT,
+                EXTRACTOR_METAFORMAT_C_STRING,
+                "text/plain",
+                (char*) &ext[1],
+                (uint8_t) ext[0]);
+      break;
     }
+    while ( (GIF_ERROR !=
+             DGifGetExtensionNext (gif_file, &ext)) &&
+            (NULL != ext) )
+      ;                   /* keep going */
+  }
 #if defined (GIF_LIB_VERSION) || GIFLIB_MAJOR < 5 || GIFLIB_MINOR < 1
   DGifCloseFile (gif_file);
 #else
@@ -146,4 +147,5 @@ EXTRACTOR_gif_extract_method (struct EXTRACTOR_ExtractContext *ec)
 #endif
 }
 
+
 /* end of gif_extractor.c */
