@@ -59,35 +59,35 @@ stndup (const char *str, size_t n)
  */
 static int
 add_keyword (enum EXTRACTOR_MetaType type,
-	     char *keyword, 
-	     EXTRACTOR_MetaDataProcessor proc,
-	     void *proc_cls)
+             char *keyword,
+             EXTRACTOR_MetaDataProcessor proc,
+             void *proc_cls)
 {
   int ret;
   char *value;
-  
+
   if (NULL == keyword)
     return 0;
-  if ( (keyword[0] == '\"') && 
+  if ( (keyword[0] == '\"') &&
        (keyword[strlen (keyword) - 1] == '\"') )
-    {
-      keyword[strlen (keyword) - 1] = '\0';
-      value = &keyword[1];
-    }
+  {
+    keyword[strlen (keyword) - 1] = '\0';
+    value = &keyword[1];
+  }
   else
     value = keyword;
   if (0 == strlen (value))
-    {
-      free (keyword);
-      return 0;
-    }
-  ret = proc (proc_cls, 
-	      "man",
-	      type,
-	      EXTRACTOR_METAFORMAT_UTF8,
-	      "text/plain",
-	      value,
-	      strlen (value)+1);
+  {
+    free (keyword);
+    return 0;
+  }
+  ret = proc (proc_cls,
+              "man",
+              type,
+              EXTRACTOR_METAFORMAT_UTF8,
+              "text/plain",
+              value,
+              strlen (value) + 1);
   free (keyword);
   return ret;
 }
@@ -102,20 +102,20 @@ add_keyword (enum EXTRACTOR_MetaType type,
  */
 static void
 find_end_of_token (size_t *end,
-		   const char *buf, 
-		   const size_t size)
+                   const char *buf,
+                   const size_t size)
 {
   int quot;
 
   quot = 0;
   while ( (*end < size) &&
-	  ( (0 != (quot & 1)) ||
-	    ((' ' != buf[*end])) ) )
-    {
-      if ('\"' == buf[*end])
-        quot++;
-      (*end)++;
-    }
+          ( (0 != (quot & 1)) ||
+            ((' ' != buf[*end])) ) )
+  {
+    if ('\"' == buf[*end])
+      quot++;
+    (*end)++;
+  }
   if (1 == (quot & 1))
     (*end) = size + 1;
 }
@@ -130,15 +130,16 @@ find_end_of_token (size_t *end,
 
 /**
  * Add a keyword to LE.
- * 
+ *
  * @param t type to use
  * @param s keyword to give to LE
  */
-#define ADD(t,s) do { if (0 != add_keyword (t, s, ec->proc, ec->cls)) return; } while (0)
+#define ADD(t,s) do { if (0 != add_keyword (t, s, ec->proc, ec->cls)) return; \
+} while (0)
 
 
 /**
- * Main entry method for the man page extraction plugin.  
+ * Main entry method for the man page extraction plugin.
  *
  * @param ec extraction context provided to the plugin
  */
@@ -152,7 +153,7 @@ EXTRACTOR_man_extract_method (struct EXTRACTOR_ExtractContext *ec)
   void *data;
   ssize_t size;
   char *buf;
-  
+
   if (0 >= (size = ec->read (ec->cls, &data, MAX_READ)))
     return;
   buf = data;
@@ -162,17 +163,17 @@ EXTRACTOR_man_extract_method (struct EXTRACTOR_ExtractContext *ec)
   /* find actual beginning of the man page (.TH);
      abort if we find non-printable characters */
   while ( (pos < size - xlen) &&
-	  ( (0 != strncmp (".TH ",
-			   &buf[pos],
-			   xlen)) || 
-	    ( (0 != pos) && 
-	      (buf[pos - 1] != '\n') ) ) )
-    {
-      if ( (! isgraph ((unsigned char) buf[pos])) && 
-	   (! isspace ((unsigned char) buf[pos])) )
-        return;
-      pos++;
-    }
+          ( (0 != strncmp (".TH ",
+                           &buf[pos],
+                           xlen)) ||
+            ( (0 != pos) &&
+              (buf[pos - 1] != '\n') ) ) )
+  {
+    if ( (! isgraph ((unsigned char) buf[pos])) &&
+         (! isspace ((unsigned char) buf[pos])) )
+      return;
+    pos++;
+  }
   if (0 != strncmp (".TH ", &buf[pos], xlen))
     return;
 
@@ -192,13 +193,13 @@ EXTRACTOR_man_extract_method (struct EXTRACTOR_ExtractContext *ec)
   if (end > size)
     return;
   if (end > pos)
-    {
-      ADD (EXTRACTOR_METATYPE_TITLE, stndup (&buf[pos], end - pos));
-      pos = end + 1;
-    }
+  {
+    ADD (EXTRACTOR_METATYPE_TITLE, stndup (&buf[pos], end - pos));
+    pos = end + 1;
+  }
   if (pos >= size)
     return;
-  
+
   /* next token is the section */
   end = pos;
   find_end_of_token (&end, buf, size);
@@ -207,62 +208,62 @@ EXTRACTOR_man_extract_method (struct EXTRACTOR_ExtractContext *ec)
   if ('\"' == buf[pos])
     pos++;
   if ((end - pos >= 1) && (end - pos <= 4))
+  {
+    switch (buf[pos])
     {
-      switch (buf[pos])
-	{
-	case '1':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("Commands")));
-	  break;
-	case '2':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("System calls")));
-	  break;
-	case '3':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("Library calls")));
-	  break;
-	case '4':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("Special files")));
-	  break;
-	case '5':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("File formats and conventions")));
-	  break;
-	case '6':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("Games")));
-	  break;
-	case '7':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("Conventions and miscellaneous")));
-	  break;
-	case '8':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("System management commands")));
-	  break;
-	case '9':
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       strdup (_("Kernel routines")));
-	  break;
-	default:
-	  ADD (EXTRACTOR_METATYPE_SECTION,
-	       stndup (&buf[pos], 1));
-	}
-      pos = end + 1;
+    case '1':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("Commands")));
+      break;
+    case '2':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("System calls")));
+      break;
+    case '3':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("Library calls")));
+      break;
+    case '4':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("Special files")));
+      break;
+    case '5':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("File formats and conventions")));
+      break;
+    case '6':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("Games")));
+      break;
+    case '7':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("Conventions and miscellaneous")));
+      break;
+    case '8':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("System management commands")));
+      break;
+    case '9':
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           strdup (_ ("Kernel routines")));
+      break;
+    default:
+      ADD (EXTRACTOR_METATYPE_SECTION,
+           stndup (&buf[pos], 1));
     }
+    pos = end + 1;
+  }
   end = pos;
 
   /* next token is the modification date */
   find_end_of_token (&end, buf, size);
   if (end > size)
-    return;  
+    return;
   if (end > pos)
-    {
-      ADD (EXTRACTOR_METATYPE_MODIFICATION_DATE, stndup (&buf[pos], end - pos));
-      pos = end + 1;
-    }
+  {
+    ADD (EXTRACTOR_METATYPE_MODIFICATION_DATE, stndup (&buf[pos], end - pos));
+    pos = end + 1;
+  }
 
   /* next token is the source of the man page */
   end = pos;
@@ -270,11 +271,11 @@ EXTRACTOR_man_extract_method (struct EXTRACTOR_ExtractContext *ec)
   if (end > size)
     return;
   if (end > pos)
-    {
-      ADD (EXTRACTOR_METATYPE_SOURCE,
-	   stndup (&buf[pos], end - pos));
-      pos = end + 1;
-    }
+  {
+    ADD (EXTRACTOR_METATYPE_SOURCE,
+         stndup (&buf[pos], end - pos));
+    pos = end + 1;
+  }
 
   /* last token is the title of the book the man page belongs to */
   end = pos;
@@ -282,11 +283,12 @@ EXTRACTOR_man_extract_method (struct EXTRACTOR_ExtractContext *ec)
   if (end > size)
     return;
   if (end > pos)
-    {
-      ADD (EXTRACTOR_METATYPE_BOOK_TITLE,
-	   stndup (&buf[pos], end - pos));
-      pos = end + 1;
-    }
+  {
+    ADD (EXTRACTOR_METATYPE_BOOK_TITLE,
+         stndup (&buf[pos], end - pos));
+    pos = end + 1;
+  }
 }
 
+
 /* end of man_extractor.c */
