@@ -26,7 +26,6 @@
 #include "test_lib.h"
 
 
-
 /**
  * Main function for the previewopus testcase.
  *
@@ -37,18 +36,17 @@
 int
 main (int argc, char *argv[])
 {
-  struct SolutionData previewopus_audio_sol[] =
-    {
-		//TODO. Can't test as it depends on the encoder.
-      { 0, 0, NULL, NULL, 0, -1 }
-    };
-  struct ProblemSet ps[] =
-    {
-      { "testdata/mpeg_alien.mpg",
-	previewopus_audio_sol },
-      { NULL, NULL }
-    };
+  struct SolutionData previewopus_audio_sol[] = {
+    // TODO. Can't test as it depends on the encoder.
+    { 0, 0, NULL, NULL, 0, -1 }
+  };
+  struct ProblemSet ps[] = {
+    { "testdata/mpeg_alien.mpg",
+      previewopus_audio_sol },
+    { NULL, NULL }
+  };
   return ET_main ("previewopus", ps);
 }
 
+
 /* end of test_thumbnailffmpeg.c */
